'use strict';
const inquirer = require('inquirer');
const commander = require('commander');

const packageJson = require('../package.json');
const utils = require('./utils');
let projectNameParam;

const program = new commander.Command(packageJson.name)
  .version(packageJson.version)
  .arguments('<template-directory>')
  .usage('<template-directory>')
  .action(name => {
    projectNameParam = name;
  })
  .parse(process.argv);

const inquirerQuestions = [
  {
    type: 'list',
    name: 'templateName',
    message: 'Which template would you like to extend ? :',
    choices: ['Mock', 'Livingstone'],
    default: 'Mock',
    filter: function (val) {
      return 'lodgify-template-' + val.toLowerCase();
    }
  }
];

if (typeof projectNameParam === 'undefined') {
  inquirerQuestions.unshift({
    type: 'input',
    name: 'projectName',
    message: 'Please specify the template directory:',
    default: 'my-lodgify-template'
  });
}

inquirer.prompt(inquirerQuestions)
  .then(utils.getTemplateVersions)
  .then(function(answers) {
    const projectName = projectNameParam || answers.projectName;
    const templateName = answers.templateName;
    const templateVersion = answers.templateVersion;

    utils.createTemplate(projectName, templateName, templateVersion)
  });