'use strict';
const chalk = require('chalk');
const path = require('path');
const tmp = require('tmp');

const tmpobj = tmp.dirSync();

const checkIfFolderAlreadyExists = require('./checkIfFolderAlreadyExists');
const copyTemplateToProjectName = require('./copyTemplateToProjectName');
const updatePackageJson = require('./updatePackageJson');
const clearLibFolder = require('./clearLibFolder');
const installDependencies = require('./installDependencies');

module.exports = (projectName, templateName, templateVersion) => {
  const root = path.resolve(projectName);

  checkIfFolderAlreadyExists(root);

  console.log();
  console.log(`Creating a new Lodgify template in ${chalk.green(root)}.`);

  copyTemplateToProjectName(root, tmpobj.name, templateName, templateVersion);
  updatePackageJson(root, projectName, templateName, templateVersion);
  clearLibFolder(root);
  installDependencies(root);

  try {
    tmpobj.removeCallback();
  } catch (ignored) {
    // Callback might fail because of file permissions.
    // OS automatically cleans it
  }

  console.log();
  console.log(`Your template has been ${chalk.green('successfully')} created.`);
  console.log(`Please switch to your new template's folder and run ${chalk.green('npm start')} to start the application.`);
};
