import React from 'react';
import PropTypes from 'prop-types';

import {Dependenceees} from '@lodgify/dependenceees';
import {
  buildDomData,
  buildLinks,
  buildScripts
} from '@lodgify/shared-legacy-dependencies';

import {
  ADVANCED_SEARCH_SCRIPTS,
  ADVANCED_SEARCH_CONTAINER_ID
} from './constants';
import {initializeAdvancedSearch} from './initializeAdvancedSearch';

/**
 * @param   {Object} props
 * @param   {Object} props.model
 * @returns {Object}
 */
export const AdvancedSearchLoader = ({model}) => {
  const {name} = model.siteModel.theme;
  return (
    <Dependenceees
      domData={buildDomData(model)}
      links={buildLinks(name)}
      scripts={buildScripts(name)}
    >
      <Dependenceees
        scripts={ADVANCED_SEARCH_SCRIPTS}
        onChildrenRendered={initializeAdvancedSearch}
      >
        <div id={ADVANCED_SEARCH_CONTAINER_ID} />
      </Dependenceees>
    </Dependenceees>
  );
};

/**
 * @type {Object}
 */
AdvancedSearchLoader.propTypes = {
  model: PropTypes.shape({
    siteModel: PropTypes.shape({
      theme: PropTypes.shape({
        name: PropTypes.string.isRequired
      })
    })
  }).isRequired
};
