import React from 'react';
import PropTypes from 'prop-types';
import {Dependenceees} from '@lodgify/dependenceees';
import {
  buildDomData,
  buildLinks,
  buildScripts
} from '@lodgify/shared-legacy-dependencies';

import {CHECKOUT_SCRIPTS, CHECKOUT_CONTAINER_ID} from './constants';
import {initializeCheckout} from './initializeCheckout';

/**
 * @param   {Object} props
 * @param   {Object} props.model
 * @returns {Object}
 */
export const CheckoutLoader = ({model}) => {
  const {name} = model.siteModel.theme;
  return (
    <Dependenceees
      domData={buildDomData(model)}
      links={buildLinks(name)}
      scripts={buildScripts(name)}
    >
      <Dependenceees
        scripts={CHECKOUT_SCRIPTS}
        onChildrenRendered={initializeCheckout}
      >
        <div id={CHECKOUT_CONTAINER_ID} />
      </Dependenceees>
    </Dependenceees>
  );
};

/**
 * @type {Object}
 */
CheckoutLoader.propTypes = {
  model: PropTypes.shape({
    siteModel: PropTypes.shape({
      theme: PropTypes.shape({
        name: PropTypes.string.isRequired
      })
    })
  }).isRequired
};
