/**
 * Check if the environment is either "dev" or "prod", therefore: isValid
 * @param  {String} env
 * @return {Boolean}
 */
const isValidEnvironment = (env) => (env && (env === 'dev' || env === 'prod'));

/**
 * Check if the page is valid
 * @param  {String} page
 * @return {Boolean}
 */
const isValidPage = (page) => (page && (page === 'livingstone-landing' || page === 'livingstone-property'));

/**
 * Dynamically loads the environment-dependant configuration and computes the needed
 * entry point
 * @param  {String} env
 * @return {Object}
 */
const configResolver = ({ env, page }) => {
  if (!isValidEnvironment(env))
    throw new Error(`No valid environment specified (dev|prod)`);

  if (!isValidPage(page))
    throw new Error(`No valid page specified (livingstone-landing|livingstone-property)`);

  // Loads from dumb @lodgify/webpack-config
  const config = require(`@lodgify/webpack-config/webpack.config.${env}.js`)({ slug: "liv" }); // eslint-disable-line

  // Loads local entry point
  const entry = require(`./entry.js`)(config, page); // eslint-disable-line

  return Object.assign({}, config, entry);
};

module.exports = configResolver;
