import { Component } from 'react';
import PropTypes from 'prop-types';

import { injectElements } from './utils/injectElements';
import { injectScripts } from './utils/injectScripts';

/**
 * @extends {React.Component}
 */
export class Dependenceees extends Component {
  /**
   * @param  {Object} props
   * @return {undefined}
   */
  constructor(props) {
    super(props);
    this.state = {
      dependenciesLoaded: false,
    };
  }

  /**
   * @return {undefined}
   */
  componentWillMount() {
    const {
      domData,
      links,
      scripts,
      shouldLoadAsync,
      onLoaded,
    } = this.props;
    const done = () => {
      onLoaded();
      this.setState({ dependenciesLoaded: true });
    };

    domData.length && injectElements(domData, 'div');
    links.length && injectElements(links, 'link');
    scripts.length
      ? injectScripts(scripts, shouldLoadAsync, done)
      : done();
  }

  /**
   * @return {undefined}
   */
  componentDidUpdate() {
    this.state.dependenciesLoaded &&
      this.props.onChildrenRendered();
  }

  /**
   * @return {Boolean|any}
   */
  render() {
    return (
      this.state.dependenciesLoaded && this.props.children
    );
  }
}

/**
 * @type {Object}
 */
Dependenceees.propTypes = {
  links: PropTypes.arrayOf(PropTypes.object),
  scripts: PropTypes.arrayOf(PropTypes.object),
  shouldLoadAsync: PropTypes.bool,
  domData: PropTypes.arrayOf(PropTypes.object),
  onLoaded: PropTypes.func,
  children: PropTypes.oneOfType([
    PropTypes.element,
    PropTypes.array,
    PropTypes.node,
  ]),
  onChildrenRendered: PropTypes.func,
};

/**
 * @type {Object}
 */
Dependenceees.defaultProps = {
  links: [],
  scripts: [],
  shouldLoadAsync: false,
  domData: [],
  onLoaded: () => {},
  children: null,
  onChildrenRendered: () => {},
};
