/**
 * Returns an `element` with required attributes.
 * @param  {Object} attributes
 * @param  {String} tagName
 * @return {Object}
 */
export const createElementWithAttributes = (
  attributes,
  tagName = 'div'
) => {
  const element = document.createElement(tagName);

  Object.entries(attributes).forEach(
    ([attribute, value]) => {
      switch (attribute) {
        case 'check':
          // Ignore the check property
          break;
        case 'dataset':
          Object.entries(attributes.dataset).forEach(
            ([key, data]) => {
              element.dataset[key] = data;
            }
          );
          break;
        default:
          element[attribute] = value;
      }
    }
  );

  return element;
};

/**
 * Injects `element`s with required attributes
 * @param  {Object[]} elements
 * @param  {String}   tagName
 * @param  {Function} [done]
 * @return {undefined}
 */
export const injectElements = (elements, tagName, done) => {
  elements.forEach(attributes => {
    const { check } = attributes;
    if (check && check()) return;

    const element = createElementWithAttributes(
      attributes,
      tagName
    );
    const target = tagName === 'link' ? 'head' : 'body';
    document[target].appendChild(element);
  });

  done && done();
};
