import {
  createElementWithAttributes,
  injectElements,
} from './injectElements';

const TAG_NAME = 'script';

/**
 * Appends `script`s and loads synchronously
 * in the order of the `scripts` array.
 * @param  {Object[]} scripts
 * @param  {Function} done
 * @return {undefined}
 */
export const syncAppendScripts = (scripts, done) => {
  // eslint-disable-next-line consistent-return
  const appendScript = (i = 0) => {
    const next = () => {
      i !== scripts.length - 1
        ? appendScript(i + 1)
        : done();
    };

    const { check } = scripts[i];
    if (check && check()) return next();

    const element = createElementWithAttributes(
      scripts[i],
      TAG_NAME
    );
    element.onload = next;
    document.body.appendChild(element);
  };

  appendScript();
};

/**
 * Injects `script`s with required attributes
 * @param  {Object[]} scripts
 * @param  {Boolean}  shouldLoadAsync
 * @param  {Function} done
 * @return {undefined}
 */
export const injectScripts = (
  scripts,
  shouldLoadAsync,
  done
) => {
  shouldLoadAsync
    ? injectElements(scripts, TAG_NAME, done)
    : syncAppendScripts(scripts, done);
};
