export const DIV_ID_MODEL = 'ldgfy-model';
export const DIV_ID_SHARED_URL = 'ldgfy-shared-url';
export const DIV_ID_WARNING = 'ldgfy-warning';

// TODO: Set these base urls from environment.
export const DEFAULTS_SERVICE = '//0.0.0.0:3030/';
const CDN_URL = '//s1.cdbcdn.com/';

export const SHARED_URL = `${CDN_URL}themes/shared/v3/assets/latest/`;
const THEMES_URL = `${CDN_URL}themes/liquid/git/live/`;

const VENDOR_PATH = 'vendor/';
const CSS_PATH = 'css/';

export const THEME_NAME_PLACEHOLDER = '{{themeName}}';

/**
 * @type {String[]}
 */
export const STYLE_SOURCES = [
  `${SHARED_URL}${VENDOR_PATH}bootstrap.3.3.2.min.css`,
  `${SHARED_URL}${VENDOR_PATH}font-awesome.4.3.0.min.css`,
  `${SHARED_URL}${VENDOR_PATH}linearicon.css`,
  `${SHARED_URL}${CSS_PATH}shared.min.css`,
  `${THEMES_URL}${THEME_NAME_PLACEHOLDER}/src/assets/css/template.min.css?f=34`,
];

const POLYFILL_BASE_URL = '//cdn.polyfill.io/v2/polyfill.js?';
const POLYFILL_OBJECT = 'Object.keys,Object.is,Object.defineProperties,Object.defineProperty,Object.create,Object.assign,Object.getOwnPropertyNames,Object.getOwnPropertyDescriptor,Object.getPrototypeOf';
const POLYFILL_ARRAY = 'modernizr:es5array';
const POLYFILL_OTHERS = 'requestAnimationFrame,screen.orientation,setImmediate,Promise,Event.DOMContentLoaded';
const POLYFILL_URL = `${POLYFILL_BASE_URL}&features=${POLYFILL_OBJECT},${POLYFILL_ARRAY},${POLYFILL_OTHERS},Intl.~locale.en`;

/**
 * @type {Object[]}
 */
export const SCRIPT_SOURCES = [
  {
    src: POLYFILL_URL,
    check: () => document.querySelector(`script[src="${POLYFILL_URL}"]`)
  },
  {
    src: '//cdnjs.cloudflare.com/ajax/libs/domready/1.0.8/ready.min.js',
    check: () => global.domready
  },
  {
    src: `${SHARED_URL}${VENDOR_PATH}jquery-1.9.1.min.js`,
    check: () => global.jQuery && global.jQuery.fn.jquery === '1.9.1'
  },
  {
    src: `${SHARED_URL}${VENDOR_PATH}jquery-migrate-1.2.1.min.js`,
    check: () => global.jQuery && global.jQuery.migrateWarnings
  },
  {
    src: `${SHARED_URL}${VENDOR_PATH}modernizr-custom.min.js`,
    check: () => global.Modernizr
  },
  {
    src: `${SHARED_URL}${VENDOR_PATH}modernizr-mq.min.js`,
    check: () => global.Modernizr && global.Modernizr.mq
  },
  {
    src: `${SHARED_URL}${VENDOR_PATH}bootstrap.3.3.2.min.js`,
    // :( Hack from: https://gist.github.com/AndersDJohnson/017f99778c06b989d3c4
    check: () => global.jQuery &&
                 global.jQuery.fn.modal &&
                 global.jQuery.fn.modal.toString().indexOf('bs.modal') === -1
  },
  {
    id: 'script-front-static',
    src: `${SHARED_URL}_front-static.min.js`,
    check: () => global.RatesGraph
  },
  {
    id: 'script-common',
    src: `${SHARED_URL}common.min.js`,
    check: () => global.I18nText
  },
  {
    id: 'script-shared',
    src: `${SHARED_URL}shared.min.js`,
    check: () => {
      const check = global.CurrencySelector;
      // Sit down before reading this...
      //
      // The shared.min.js script checks for the existence of a script
      // tag with a src matching /checkout\.min/. We need this check to
      // pass in order for CheckoutPaymentApp to work.
      //
      // BUT the real script tag with that src cannot be appended to the
      // DOM until after the shared.min.js script has run.
      //
      // SO here we specify a dummy tag to a non existent script and block
      // loading by using an invalid type.
      //
      // Mindblowing.
      //
      // I am including this functionality in `check` because it runs
      // immediately before `shared.min.js` is appended to the DOM.
      if (!check) {
        const script = document.createElement('script');
        script.src = 'checkout.min.js';
        script.type = 'muuaahahahaa';
        document.body.appendChild(script);
      }
      return check;
    }
  },
  {
    id: 'script-initialiser',
    src: `${SHARED_URL}initialiser.min.js`,
    check: () => global.ldgfy && global.ldgfy.template
  },
  {
    id: 'script-template',
    src: `${THEMES_URL}${THEME_NAME_PLACEHOLDER}/src/assets/js/template.min.js`,
    check: () => global.templateVersion && global.templateVersion.version
  }
];
