import {snakifyKeys} from './utils/snakifyKeys';
import {stringifyAndEncode} from './utils/stringifyAndEncode';
import {
  DEFAULTS_SERVICE,
  DIV_ID_MODEL,
  DIV_ID_SHARED_URL,
  DIV_ID_WARNING,
  SHARED_URL,
  STYLE_SOURCES,
  SCRIPT_SOURCES,
  THEME_NAME_PLACEHOLDER
} from './constants';

/**
 * Builds an array of objects describing data
 * to be injected into the DOM.
 * @param  {Object}   siteModel
 * @param  {Object}   pageModel
 * @return {Object[]}
 */
export const buildDomData = ({
  siteModel,
  pageModel
}) => {

  const siteModelCopy = {
    ...siteModel,
    defaultsUrl: `${DEFAULTS_SERVICE}${siteModel.defaultsUrl}`
  };

  const domData = [
    {
      id: DIV_ID_MODEL,
      dataset: {
        model: stringifyAndEncode(snakifyKeys(siteModelCopy)),
        colors: JSON.stringify(siteModel.theme.palette),
        currencies: JSON.stringify(siteModel.availableCurrencies),
        pageoptions: JSON.stringify(pageModel.pageOptions),
      },
      check: () => document.querySelector(`div#${DIV_ID_MODEL}`)
    },
    {
      id: DIV_ID_SHARED_URL,
      dataset: {url: SHARED_URL},
      check: () => document.querySelector(`div#${DIV_ID_SHARED_URL}`)
    },
    {
      id: DIV_ID_WARNING,
      dataset: {warning: false},
      check: () => document.querySelector(`div#${DIV_ID_WARNING}`)
    }
  ];

  return domData;

};

/**
 * Builds an array of objects describing links
 * to be injected into the DOM.
 * @param  {String} themeName
 * @return {Object[]}
 */
export const buildLinks = themeName => (

  STYLE_SOURCES.map(source => {
    const href = source.replace(THEME_NAME_PLACEHOLDER, themeName.toLowerCase());
    return {
      href,
      type: 'text/css',
      rel: 'stylesheet',
      check: () => document.querySelector(`link[href="${href}"]`)
    };
  })

);

/**
 * Builds an array of objects describing scripts
 * to be injected into the DOM.
 * @param  {String}   themeName
 * @return {Object[]}
 */
export const buildScripts = themeName => (

  SCRIPT_SOURCES.map(source => ({
    ...source,
    src: source.src.replace(THEME_NAME_PLACEHOLDER, themeName.toLowerCase())
  }))

);
