import {
  buildDomData,
  buildLinks,
  buildScripts
} from './dependencyBuilders';
import {
  DIV_ID_MODEL,
  DIV_ID_SHARED_URL,
  DIV_ID_WARNING,
  SHARED_URL,
  MODEL
} from './constants';

jest.mock('./constants');

describe('utils/dependencyBuilders.js', () => {

  describe('buildDomData', () => {

    test('should return spec for #ldgfy-model at index 0', () => {

      const {siteModel, pageModel} = MODEL;

      expect(
        buildDomData(MODEL)[0]
      ).toEqual(
        expect.objectContaining({
          id: DIV_ID_MODEL,
          dataset: expect.objectContaining({
            model: expect.stringContaining(siteModel.apiToken),
            colors: expect.stringMatching(JSON.stringify(siteModel.theme.palette)),
            currencies: expect.stringMatching(JSON.stringify(siteModel.availableCurrencies)),
            pageoptions: expect.stringMatching(JSON.stringify(pageModel.pageOptions)),
          }),
          check: expect.any(Function)
        })
      );

    });

    test('should return spec for #ldgfy-shared-url at index 1', () => {

      expect(
        buildDomData(MODEL)[1]
      ).toEqual(
        expect.objectContaining({
          id: DIV_ID_SHARED_URL,
          dataset: expect.objectContaining({
            url: SHARED_URL
          }),
          check: expect.any(Function)
        })
      );

    });

    test('should return spec for #ldgfy-warning at index 2', () => {

      expect(
        buildDomData(MODEL)[2]
      ).toEqual(
        expect.objectContaining({
          id: DIV_ID_WARNING,
          dataset: expect.objectContaining({
            warning: false
          }),
          check: expect.any(Function)
        })
      );

    });

  });

  describe('buildLinks', () => {

    test('should return the correct array', () => {

      expect(
        buildLinks(MODEL.siteModel.theme.name)
      ).toEqual(
        expect.arrayContaining([
          {
            href: '',
            type: 'text/css',
            rel: 'stylesheet',
            check: expect.any(Function)
          },
          {
            href: 'livingstone',
            type: 'text/css',
            rel: 'stylesheet',
            check: expect.any(Function)
          },

        ])
      );

    });

  });

  describe('buildScripts', () => {

    test('should return the correct array', () => {

      expect(
        buildScripts(MODEL.siteModel.theme.name)
      ).toEqual(
        expect.arrayContaining([
          {
            src: '',
          },
          {
            src: 'livingstone',
            id: 'someId'
          },

        ])
      );

    });

  });

});
