/**
 * @param  {String} camelCaseString - a string in camelCase
 * @return {String}                 - the string in snake_case
 */
export const snakifyString = camelCaseString => (
  camelCaseString.replace(/[A-Z]{1}/g, match => `_${match.toLowerCase()}`)
);

/**
 * Add snake_case equivalent for all camelCase keys on an object, recursively
 * @param  {Object} object
 * @return {Object}
 */
export const snakifyKeys = object => {
  for (const [key, value] of Object.entries(object)) {
    if (value && typeof value === 'object') snakifyKeys(value);
    object[snakifyString(key)] = value; // eslint-disable-line no-param-reassign
  }
  return object;
};
