import {
  snakifyKeys,
  snakifyString
} from './snakifyKeys';

describe('utils/snakifyKeys.js', () => {

  describe('snakifyKeys', () => {

    it('should add snake_case equivalent for all camelCase keys on an object', () => {

      const before = {
        key: 'value',
        otherKey: 'otherValue',
        yetAnotherKey: 'yetAnotherValue'
      };
      const after = {
        key: 'value',
        otherKey: 'otherValue',
        other_key: 'otherValue',
        yetAnotherKey: 'yetAnotherValue',
        yet_another_key: 'yetAnotherValue',
      };

      expect(snakifyKeys(before)).toEqual(after);

    });

    it('should recur down the object hierarchy', () => {

      const before = {
        parent: {
          child: {
            grandChild: 'cute'
          },
          otherChild: 'ugly'
        }
      };
      const after = {
        parent: {
          child: {
            grandChild: 'cute',
            grand_child: 'cute'
          },
          otherChild: 'ugly',
          other_child: 'ugly'
        }
      };

      expect(snakifyKeys(before)).toEqual(after);

    });

  });

  describe('snakifyString', () => {

    it('should convert camelCase string to snake_case string', () => {

      expect(
        snakifyString('camelTurnsIntoASnake')
      ).toBe(
        'camel_turns_into_a_snake'
      );

    });

    it('should not modify lowercase string', () => {

      expect(
        snakifyString('nothingtoseehere')
      ).toBe(
        'nothingtoseehere'
      );

    });

  });

});
