import {
  replacer,
  stringifyAndEncode
} from './stringifyAndEncode';

describe('utils/stringifyAndEncode.js', () => {

  describe('replacer', () => {

    test('it should return non-string values unchanged', () => {

      expect(replacer(undefined, true)).toBe(true);
      expect(replacer(undefined, null)).toBe(null);
      expect(replacer(undefined, undefined)).toBe(undefined);
      expect(replacer(undefined, 155)).toBe(155);
      expect(replacer(undefined, 'calcots')).toBe('calcots');
      const symbol = Symbol('messi');
      expect(replacer(undefined, symbol)).toBe(symbol);
      const object = {};
      expect(replacer(undefined, object)).toBe(object);

    });

    test('it should encode HTML strings', () => {

      const before = `<tag id='yo' class="hey">&</tag>`;
      const after = `&lt;tag id=&#39;yo&#39; class=&quot;hey&quot;&gt;&amp;&lt;/tag&gt;`;

      expect(
        replacer(undefined, before)
      ).toBe(
        after
      );

    });

    test('it should leave other strings unchanged', () => {

      const allOtherAscii = ' !#$%()*+,-./0123456789:;=?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~';
      expect(
        replacer(undefined, allOtherAscii)
      ).toBe(
        allOtherAscii
      );

    });

  });

  describe('stringifyAndEncode', () => {

    test('it should stringify to JSON and leave the rest to `replacer`', () => {

      const before = {key: 'value', html: '<tag>'};
      const after = JSON.stringify({...before, html: '&lt;tag&gt;'});
      expect(
        stringifyAndEncode(before)
      ).toBe(
        after
      );

    });

  });

});
