const getCssLoaders = (isProd = false, slug) => [
  {
    loader: 'css-loader',
    options: {
      importLoaders: 1,
      modules: true,
      localIdentName: `${slug}__[name]__[local]`,
      minimize: isProd,
      sourceMap: !isProd
    }
  },
  {
    loader: 'postcss-loader',
    options: {
      // Necessary for external CSS imports to work
      // https://github.com/facebookincubator/create-react-app/issues/2677
      ident: 'postcss',
      plugins: () => [
        require('postcss-flexbugs-fixes'),
        require('autoprefixer')({
          browsers: ['>1%', 'last 4 versions', 'Firefox ESR', 'not ie < 9'],
          flexbox: 'no-2009'
        })
      ],
      sourceMap: !isProd
    }
  }
];

module.exports = function(slug) {
  return {
    jsxLoader: {
      test: /\.jsx?$/,
      exclude: /node_modules/,
      use: {
        loader: 'babel-loader',
        options: {
          presets: [
            [
              'airbnb',
              { targets: { browsers: ['>1%', 'last 4 versions', 'Firefox ESR', 'not ie < 10'] } }
            ]
          ]
        }
      }
    },
    cssLoaders: getCssLoaders(false, slug),
    cssLoadersProd: getCssLoaders(true, slug),
    imagesLoader: {
      test: [/\.bmp$/, /\.gif$/, /\.jpe?g$/, /\.png$/],
      loader: require.resolve('url-loader'),
      options: {
        limit: 10000,
        name: 'static/[name].[hash:8].[ext]'
      }
    },
    filesLoader: {
      include: [/\.svg$/],
      loader: require.resolve('file-loader'),
      options: {
        name: 'public/static/[name].[ext]'
      }
    },
    resolveExtensions: ['.js', '.json', '.jsx']
  };
};
