const webpack = require('webpack');
const path = require('path');

const rootPath = path.resolve('.');

const devServer = {
  hot: true,
  host: '0.0.0.0',
  port: 3000,
  open: true,
  openPage: '',
  contentBase: path.join(rootPath, 'lib/public/')
};

/**
 * Return array of loader objects
 * @param  {Object} common
 * @return {Object[]}
 */
const getLoaders = (common) => ([
  common.jsxLoader,

  {
    test: /\.css$/,
    use: ['style-loader', 'css-loader'],
    include: [/node_modules/, /lib/]
  },
  {
    test: /\.css$/,
    use: ['style-loader', ...common.cssLoaders],
    exclude: [/node_modules/, /lib/]
  },
  {
    test: /\.less$/,
    use: [
      'style-loader',
      ...common.cssLoaders,
      { loader: 'less-loader', options: { sourceMap: true } }
    ],
    exclude: /node_modules/
  },
  {
    test: /\.scss$/,
    use: [
      'style-loader',
      ...common.cssLoaders,
      { loader: 'sass-loader', options: { sourceMap: true } }
    ],
    exclude: /node_modules/
  },
  common.imagesLoader,
  common.filesLoader
]);

/**
 * Resolves webpack configuration
 * @param  {Object} env
 * @return {Object}
 */
const configResolver = (env) => {
  const common = require('./common')(env.slug);

  const config = {
    devtool: 'source-map',
    module: {
      loaders: getLoaders(common)
    },
    node: {
      fs: 'empty'
    },
    resolve: {
      extensions: common.resolveExtensions
    },
    plugins: [
      // enable HMR globally
      new webpack.HotModuleReplacementPlugin(),
      // prints more readable module names in the browser console on HMR updates
      new webpack.NamedModulesPlugin(),
      // do not emit compiled assets that include errors
      new webpack.NoEmitOnErrorsPlugin(),
      new webpack.EnvironmentPlugin({
        NODE_ENV: 'development',
        BROWSER: true
      })
    ],
    devServer
  };

  return Object.assign({}, config);
};

module.exports = configResolver;
