const path = require('path');
const webpack = require('webpack');
const ExtractTextPlugin = require('extract-text-webpack-plugin');

const rootPath = path.resolve('.');

/**
 * Return array of loader objects
 * @param  {Object} common
 * @return {Object[]}
 */
const getLoaders = (common) => ([
  common.jsxLoader,
  {
    test: /\.css$/,
    use: ExtractTextPlugin.extract({
      fallback: 'style-loader',
      use: common.cssLoadersProd
    }),
    exclude: /node_modules/
  },
  {
    test: /\.css$/,
    use: ExtractTextPlugin.extract({
      fallback: 'style-loader',
      use: ['css-loader']
    }),
    include: /node_modules/
  },
  {
    test: /\.scss$/,
    use: ExtractTextPlugin.extract({
      fallback: 'style-loader',
      use: [...common.cssLoadersProd, 'sass-loader']
    })
  },
  {
    test: /\.less$/,
    use: ExtractTextPlugin.extract({
      fallback: 'style-loader',
      use: [...common.cssLoadersProd, 'less-loader']
    })
  },
  common.imagesLoader,
  common.filesLoader
]);

/**
 * Resolves webpack configuration
 * @param  {Object} env
 * @return {Object}
 */
const configResolver = (env) => {
  const common = require('./common')(env.slug);

  const config = {
    bail: true,
    devtool: false,
    module: {
      loaders: getLoaders(common)
    },
    resolve: {
      extensions: common.resolveExtensions
    },
    plugins: [
      new ExtractTextPlugin({
        filename: 'styles.css'
      }),
      new webpack.optimize.UglifyJsPlugin({
        compress: {
          warnings: false,
          // Disabled because of an issue with Uglify breaking seemingly valid code:
          // https://github.com/facebookincubator/create-react-app/issues/2376
          // Pending further investigation:
          // https://github.com/mishoo/UglifyJS2/issues/2011
          comparisons: false
        },
        output: {
          comments: false,
          // Turned on because emoji and regex is not minified properly using default
          // https://github.com/facebookincubator/create-react-app/issues/2488
          ascii_only: true
        },
        sourceMap: false
      }),
      new webpack.EnvironmentPlugin({
        NODE_ENV: 'production',
        BROWSER: true
      })
    ]
  };

  return Object.assign({}, config);
};

module.exports = configResolver;
