/* eslint-disable jsx-a11y/tabindex-no-positive */
import React from 'react';

import {
  I18nText,
  I18nPlainText
} from '../I18n';

import styles from './CallMeBack.scss';

const model = {
  time_zones: [
    {
      id: 'Aleutian Standard Time',
      name: '(-10:00)  Aleutian Islands',
    },
    {
      id: 'Hawaiian Standard Time',
      name: '(-10:00)  Hawaii',
    },
    {
      id: 'Marquesas Standard Time',
      name: '(-09:30)  Marquesas Islands',
    },
  ],
  times: [
    {
      id: 0,
      name: '00:00 - 02:00',
    },
    {
      id: 2,
      name: '02:00 - 04:00',
    },
    {
      id: 4,
      name: '04:00 - 06:00',
    },
  ],
  properties: [
    {
      id: 182011,
      name: 'just another property',
    },
    {
      id: 182010,
      name: 'Second property',
    },
  ],
};

const displayNone = {
  display: 'none',
};

const CallMeBackWidget = () => (
  <section className={`${styles.subtleBox} ${styles.calleMeBack}`}>
    <div className="mainContainer">
      <form
        action="{{model.post_url}}"
        className="callmeback-form"
        id="callmeback-form"
        method="post"
        data-ajax="true"
        data-ajax-method="POST"
        data-ajax-begin="ldgfy.callmeback.onBeforeCallMeBack"
        data-ajax-failure="ldgfy.callmeback.onErrorCallMeBack"
        data-ajax-success="ldgfy.callmeback.onSuccessCallMeBack"
      >
        {/* {% content_for_form CallMeBack %} */}

        <div className={styles.row}>
          <div className="col-md-12">
            <h2>
              <I18nText keyName="TH_WI_CallMeBack_Title" />
            </h2>
          </div>
        </div>

        <div className={styles.row}>
          <div className="col-md-12">
            <div
              className={`${styles.alert} validation-summary-valid alert-danger`}
              data-valmsg-summary="true"
              id="callmeback-validation-summary"
            >
              <ul>
                <li style={{ display: 'none' }} />
              </ul>
            </div>

            <div id="callmeback-ok" className="alert alert-success" style={displayNone}>
              <span>
                <I18nText keyName="TH_WI_CallMeBack_RequestSentOk" />
              </span>
            </div>

            <div id="callmeback-ko" className="alert alert-danger" style={displayNone}>
              <span>
                <I18nText keyName="TH_WI_CallMeBack_RequestSentKo" />
              </span>
            </div>
          </div>
        </div>

        <div className={styles.row}>
          <div className="col-md-12">
            <div className="form-group">
              <input
                id="Name"
                name="Name"
                className="form-control"
                tabIndex="101"
                type="text"
                defaultValue={model.name}
                placeholder={<I18nPlainText keyName="G_Name" />}
                data-val="true"
                data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'G_Name']} />}
              />
            </div>
          </div>
        </div>
        <div className={styles.row}>
          <div className="col-md-12">
            <div className="form-group">
              <input
                id="Email"
                name="Email"
                className="form-control"
                tabIndex="102"
                type="text"
                defaultValue={model.email}
                placeholder={<I18nPlainText keyName="G_Email" />}
                data-val="true"
                data-val-email={<I18nPlainText keyName={['G_Error_EmailNotValid', 'G_Email']} />}
                data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'G_Email']} />}
              />
            </div>
          </div>
        </div>
        <div className={styles.row}>
          <div className="col-md-12">
            <div className="form-group">
              <input
                className="form-control intlphone"
                type="tel"
                placeholder={<I18nPlainText keyName="G_Phone" />}
                id="Phone"
                tabIndex="103"
                defaultValue=""
              />
              <input type="hidden" id="PhoneValueCall" name="Phone" defaultValue="" />
            </div>
          </div>
        </div>
        <div className={styles.row}>
          <div className="col-md-12 callmeback-datepicker">
            <div className="form-group datepicker">
              <input
                id="Date"
                name="Date"
                tabIndex="104"
                className="form-control"
                placeholder={<I18nPlainText keyName="TH_WI_CallMeBack_Date" />}
                size="16"
                type="text"
                data-val="true"
                data-val-date={<I18nPlainText keyName={['G_Error_DateField', 'TH_WI_CallMeBack_Date']} />}
              />
            </div>
          </div>
        </div>
        <div className={styles.row}>
          <div className="col-md-6">
            <div className={styles.formGroup}>
              <select
                autoComplete="off"
                tabIndex="105"
                className="form-control"
                id="SelectedTimeZoneId"
                name="SelectedTimeZoneId"
              >
                {model.time_zones.map(tz => (
                  <option value={tz.id} key={tz.id}>
                    {tz.name}
                  </option>
                ))}
              </select>
              <select
                autoComplete="off"
                tabIndex="106"
                className="form-control"
                id="SelectedTimeId"
                name="SelectedTimeId"
              >
                {model.times.map(time => (
                  // You need to escape
                  // <option value="{{time.id}}">{{time.name | escape}}</option>
                  <option value={time.id} key={time.id}>
                    {time.name}
                  </option>
                ))}
              </select>
            </div>
          </div>
        </div>
        <div className={styles.row}>
          <div className="col-md-12">
            <div className="form-group">
              <select
                autoComplete="off"
                tabIndex="107"
                className="form-control"
                id="SelectedHouseId"
                name="SelectedHouseId"
                data-val="true"
                data-val-number={<I18nPlainText keyName={['G_Error_NumberField', 'G_Property']} />}
              >
                <option defaultValue=""><I18nPlainText keyName="G_Property" /></option>
                {model.properties.map(property => (
                  // You need to escape
                  // <option value="{{property.id}}">{{property.name | escape}}</option>
                  <option defaultValue={property.id} key={property.id}>
                    {property.name}
                  </option>
                ))}
              </select>
            </div>
          </div>
        </div>
        <div className={styles.row}>
          <div className="col-md-12">
            <div className="form-group">
              <textarea
                cols="20"
                id="Notes"
                className="form-control"
                tabIndex="108"
                name="Notes"
                placeholder={<I18nPlainText keyName="TH_WI_CallMeBack_Notes" />}
                rows="5"
              />
            </div>
          </div>
        </div>
        <div className={styles.row}>
          <div className="col-md-12">
            <div className="form-group">
              <button
                id="login-send"
                type="submit"
                tabIndex="109"
                className="btn btn-primary btn-block"
              >
                <I18nText isText keyName="G_Button_Send" />
              </button>
            </div>
          </div>
        </div>
      </form>
    </div>
  </section>
);

export default CallMeBackWidget;
/* eslint-enable */
