/* eslint-disable jsx-a11y/tabindex-no-positive */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { isEmailValid } from '@lodgify/utils';

import styled from 'styled-components';
import Phone from 'react-phone-number-input';
import 'react-phone-number-input/rrui.css';
import 'react-phone-number-input/style.css';
import serialize from 'form-serialize';
import fetchJsonp from 'fetch-jsonp';

import { IP_LOOK_UP, MOCK_URL, HEADERS } from '../../../utils/constants';
import {
  I18nText,
  I18nPlainText
} from '../I18n';
import styles from './contactForm.scss';

const Button = styled.button`
  background: ${props => props.theme.palette.action || '#fac600'};
  border-radius: 40px;
  font-size: 0.75rem;
  border: none;
  width: 140px;
  height: 40px;
  display: inline-block;
  vertical-align: top;
  margin-top: 2em;
  cursor: pointer;
`;

const Title = styled.h2`
  font-family: ${props => props.theme.headerFont.name || 'Caveat'};
  text-align: center;
  font-size: 1.7rem;
`;

class ContactForm extends Component {
  constructor(props) {
    super(props);
    this.state = {
      fields: {
        OwnerHomepageId: 787957,
        Name: null,
        Comment: null,
        Email: null,
      },
      errors: [
        {
          name: 'Name',
          text: 'G_Error_RequiredField G_Name',
        },
        {
          name: 'Email',
          text: 'G_Error_RequiredField G_Email',
        },
        {
          name: 'Comment',
          text: 'G_Error_RequiredField G_Comment',
        },
      ],
    };
    this.handleChange = this.handleChange.bind(this);
    this.submitForm = this.submitForm.bind(this);
    this.onChangeHouseContact = this.onChangeHouseContact.bind(this);
    this.renderSuccessMessage = this.renderSuccessMessage.bind(this);
  }

  componentWillMount() {
    fetchJsonp(IP_LOOK_UP, {})
      .then(response => response.json())
      .then(json => {
        this.setState({
          ...this.state,
          country: json.country,
        });
      });
  }

  onChangeHouseContact(e) {
    if (e.target.value !== 'G_Property') {
      const url = `${MOCK_URL}${this.props.postUrlRooms}&hid=${e.target.value}`;
      fetch(url, {
        method: 'GET',
        headers: {
          'Content-Type': HEADERS.contentTypeJson,
          'X-Requested-With': HEADERS.requestWith,
        },
      })
        .then(res => res.json())
        .then(rooms => {
          this.setState({
            ...this.state,
            rooms,
          });
        });
    } else {
      this.setState({
        ...this.state,
        rooms: null,
      });
    }
  }

  handleChange(e, element) {
    const state = this.state;
    // Need to pass phone because
    // the comp does not return a target but
    // directly the value
    if (element === 'phone') {
      state.fields[element] = element;
    } else {
      state.fields[e.target.name] = e.target.value;
    }
    // If all fields are valid
    if (
      state.fields.Name &&
      state.fields.Email &&
      isEmailValid(state.fields.Email) &&
      state.fields.Comment
    ) {
      this.setState({
        ...this.state,
        hasError: false,
        emailValidated: false,
      });
    } else {
      this.setState({
        ...this.state,
        state,
      });
    }
  }

  submitForm(e) {
    e.preventDefault();

    const data = serialize(e.target);
    if (!this.state.fields.Name || !this.state.fields.Comment || !this.state.fields.Email) {
      this.setState({
        ...this.state,
        hasError: true,
      });
      return null;
    }
    this.setState({
      ...this.state,
      hasError: false,
    });
    fetch(`${MOCK_URL}${this.props.postUrl}`, {
      method: 'POST',
      mode: 'CORS',
      headers: {
        'X-Requested-With': 'XMLHttpRequest',
        Accept: '*.*',
        'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
      },
      body: data,
    }).then(res => {
      if (res.statusText === 'OK') {
        this.setState({
          ...this.state,
          success: true,
        });
      }
    });

    this.setState({
      ...this.state,
      hasError: false,
    });
    fetch(`${MOCK_URL}${this.props.postUrl}`, {
      method: 'POST',
      mode: 'CORS',
      headers: {
        'X-Requested-With': 'XMLHttpRequest',
        Accept: '*.*',
        'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
      },
      body: data,
    }).then(_data => {
      if (_data.statusText === 'OK') {
        this.setState({
          ...this.state,
          success: true,
        });
      }
    });

    return null;
  }

  renderSuccessMessage() {
    if (this.state.success) {
      return (
        <div className={`${styles.alert} ${styles.success}`}>
          Your contact request has been sent succesfully
        </div>
      );
    }
    return null;
  }

  renderErrorMessage() {
    const errors = this.state.errors;
    const fields = this.state.fields;
    if (!isEmailValid(this.state.fields.Email) && this.state.fields.Email) {
      return <li>Email not valid</li>;
    }
    return errors.map(err =>
      Object.keys(fields).map(
        field => !fields[field] && field === err.name && <li key={err.name}>{`${err.text}`}</li>,
      ),
    );
  }

  renderRooms() {
    if (!this.state.rooms) {
      return <option value={<I18nPlainText keyName="G_Rooms" />}><I18nPlainText keyName="G_Rooms" /></option>;
    }
    return (
      this.state.rooms &&
      this.state.rooms.map(room => (
        <option key={room.Id} value={room.Id}>
          {room.Name}
        </option>
      ))
    );
  }

  render() {
    return (
      <div
        className={`${styles.formWidgetContainer} ${
          this.props.visible ? styles.visible : styles.hidden
        }`}
      >
        <section className={`${styles.contactWidgetFormContainer}`} id="Contact">
          <div className={styles.container}>
            <ul className={`${styles.alert} ${this.state.hasError && styles.error}`}>
              {this.state.hasError && this.renderErrorMessage()}
            </ul>
            {this.state.success && this.renderSuccessMessage()}
            <form
              onSubmit={this.submitForm}
              ref={c => {
                this.form = c;
              }}
              className={styles.widgetContactForm}
              id="contact-form"
              method="post"
            >
              <input
                type="hidden"
                value={this.props.model && this.props.model.websiteId}
                name="OwnerHomepageId"
                id="OwnerHomepageId"
              />
              <div className={styles.row}>
                <div className={styles.row}>
                  <Title>
                    <I18nText keyName="G_Contact" />
                  </Title>
                </div>
                <div className={styles.row}>
                  <input
                    id="Name"
                    name="Name"
                    className={`${this.state.hasError &&
                      !this.state.fields.Name &&
                      styles.inputError}`}
                    tabIndex="1"
                    type="text"
                    defaultValue={this.state.name}
                    onChange={this.handleChange}
                    placeholder={<I18nPlainText keyName="G_Name" />}
                  />
                </div>
                <div className={styles.row}>
                  <Phone
                    placeholder={<I18nPlainText keyName="G_Phone" />}
                    value={this.state.phone}
                    onChange={e => {
                      this.handleChange(e, 'phone');
                    }}
                    country={this.state.country || 'US'}
                    indicateInvalid
                    defaultValue={this.state.Phone}
                  />
                </div>
                <div className={styles.row}>
                  <input
                    id="Email"
                    name="Email"
                    className={`${this.state.hasError &&
                      !this.state.fields.Email &&
                      styles.inputError}`}
                    tabIndex="3"
                    type="text"
                    defaultValue={this.state.Email}
                    onChange={this.handleChange}
                    placeholder={<I18nPlainText keyName="G_Email" />}
                    data-val="true"
                  />
                </div>
                <div className={`${styles.row} ${styles.flexedRow}`}>
                  <input
                    id="ContactArrival"
                    name="ContactArrival"
                    tabIndex="4"
                    placeholder={<I18nPlainText keyName="G_Arrival" />}
                    className={`${this.state.fields && !this.state.fields.Name && styles.error}`}
                    size="16"
                    type="text"
                    defaultValue={this.state.ContactArrival}
                    onChange={this.state.handleChange}
                    data-val="true"
                    data-val-date={<I18nPlainText keyName={['G_Error_DateField', 'G_Arrival']} />}
                    data-val-departure-name="ContactDeparture"
                  />
                  <input
                    id="ContactDeparture"
                    name="ContactDeparture"
                    tabIndex="5"
                    placeholder={<I18nPlainText keyName="G_Departure" />}
                    size="16"
                    type="text"
                    defaultValue={this.state.ContactDeparture}
                    onChange={this.handleChange}
                    className=""
                    data-val="true"
                    data-val-date={<I18nPlainText keyName={['G_Error_DateField', 'G_Departure']} />}
                    data-val-dategreaterthan={<I18nPlainText keyName="G_DepartureGreaterThanArrival" />}
                    data-val-dategreaterthan-otherpropertyname="ContactArrival"
                  />
                </div>

                <div className={`${styles.row} ${styles.selectRow}`}>
                  <select
                    d="People"
                    name="People"
                    value={this.state.People}
                    onChange={this.handleChange}
                    className={styles.peopleSelect}
                  >
                    <option value="null">{<I18nPlainText keyName="G_People" />}</option>
                    <option value="1">1</option>
                    <option value="2">2</option>
                    <option value="3">3</option>
                    <option value="4">4</option>
                    <option value="5">5</option>
                    <option value="6">6</option>
                    <option value="7">7</option>
                    <option value="8">8</option>
                    <option value="9">9</option>
                    <option value="10">10</option>
                  </select>
                  {!this.props.rooms ? (
                    <div>
                      <select
                        autoComplete="off"
                        className={styles.roomSelect}
                        id="SelectedHouseId"
                        name="SelectedHouseId"
                        onChange={this.onChangeHouseContact}
                        data-val="true"
                        data-val-number={<I18nPlainText keyName={['G_Error_NumberField', 'G_Property']} />}
                      >
                        <option defaultValue="">{<I18nPlainText keyName="G_Property" />}</option>
                        {this.props.properties.map(property => (
                          // Need to escape
                          <option key={property.id} value={property.id}>
                            {property.name}
                          </option>
                        ))}
                      </select>
                      <select
                        id="SelectedRoomTypeId"
                        name="SelectedRoomTypeId"
                        autoComplete="off"
                        className={styles.roomSelect}
                        data-val="true"
                        data-val-number={<I18nPlainText keyName={['G_Error_NumberField', 'G_Rooms']} />}
                        disabled={!this.state.rooms && 'disabled'}
                      >
                        {this.renderRooms()}
                      </select>
                    </div>
                  ) : (
                    <select
                      id="SelectedRoomTypeId"
                      name="SelectedRoomTypeId"
                      autoComplete="off"
                      className={styles.roomSelect}
                      data-val="true"
                      onChange={this.selectRoom}
                      data-val-number={<I18nPlainText keyName={['G_Error_NumberField', 'G_Rooms']} />}
                    >
                      <option defaultValue="">{<I18nPlainText keyName="G_Rooms" />}</option>
                      {this.props.rooms.map(room => (
                        // need to escape
                        <option key={room.id} value={room.id}>
                          {room.name}
                        </option>
                      ))}
                    </select>
                  )}
                </div>
                <div className={styles.row}>
                  <textarea
                    cols="20"
                    id="Comment"
                    name="Comment"
                    rows="5"
                    tabIndex="7"
                    defaultValue={''}
                    className={`${this.state.hasError &&
                      !this.state.fields.Comment &&
                      styles.inputError}`}
                    value={this.state.Comment}
                    onChange={this.handleChange}
                    placeholder={<I18nPlainText keyName="G_Comment" />}
                  />
                </div>

                {this.props.websiteOptions ? (
                  <div className={styles.row}>
                    <div className="captcha-img">
                      <img
                        src="/signupcode.ashx?seed=ContactSecurityCode"
                        alt=""
                        style={{ minWidth: '150px' }}
                        data-resize="false"
                      />
                    </div>
                    <input
                      placeholder={<I18nPlainText keyName="G_CaptchaEnter" />}
                      autoComplete="off"
                      id="CaptchaCode"
                      maxLength="15"
                      name="CaptchaCode"
                      tabIndex="8"
                      type="text"
                      defaultValue=""
                      className={`${this.state.fields && !this.state.fields.Name && styles.error}`}
                    />
                  </div>
                ) : null}

                <div className={styles.row}>
                  {/* <I18nText keyName="G_Button_Reset" /> */}
                  <Button
                    id="contact-send"
                    type="submit"
                    className=""
                    data-loading-text={<I18nPlainText keyName="G_Button_Loading" />}
                    tabIndex="9"
                  >
                    <I18nText keyName="G_Button_Send" />
                  </Button>
                </div>
              </div>
            </form>
          </div>
        </section>
      </div>
    );
  }
}

ContactForm.defaultProps = {
  visible: false,
  websiteOptions: [],
  rooms: [],
  properties: [],
  model: {},
  postUrl: '',
  postUrlRooms: '',
};

ContactForm.propTypes = {
  visible: PropTypes.bool,
  websiteOptions: PropTypes.arrayOf(PropTypes.any),
  rooms: PropTypes.arrayOf(PropTypes.object),
  properties: PropTypes.arrayOf(PropTypes.object),
  model: PropTypes.objectOf(PropTypes.any),
  postUrl: PropTypes.string,
  postUrlRooms: PropTypes.string,
};

export default ContactForm;
