import React, { Component } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import MediaQuery from 'react-responsive';

import ContactFormPopUp from './ContactForm';

// import styles from './contactForm.scss';

const Button = styled.button`
  background: ${props => props.theme.palette.action || '#fac600'};
  border-radius: 40px;
  font-size: 0.75rem;
  border: none;
  width: 140px;
  height: 40px;
  display: inline-block;
  vertical-align: top;
  margin-top: 2em;
  cursor: pointer;
`;

const Title = styled.h2`
  font-family: ${props => props.theme.titleFont.name || 'Caveat'};
`;

const BioContainer = styled.div`
  display: inline-block;
  margin-left: 3em;
  max-width: 70%;
  vertical-align: top;
  @media screen and (max-width: 620px) {
    max-width: 100%;
    margin: 0;
    width: 95%;
    padding: 1em;
    display: block;
  }
`;

const Container = styled.div``;

class ContactForm extends Component {
  constructor(props) {
    super(props);
    this.state = {
      visible: false,
    };
    this.renderContactForm = this.renderContactForm.bind(this);
  }

  renderContactForm() {
    this.setState({
      visible: !this.state.visible,
    });
  }

  render() {
    const popupProps = Object.assign({}, this.props, this.state);
    return (
      <Container id="Contact">
        <MediaQuery maxWidth={620} values={{ width: 620 }}>
          <BioContainer>
            <Title>{this.props.ownerName}</Title>
            <p>{this.props.ownerBio}</p>
          </BioContainer>
          <Button onClick={this.renderContactForm}>Contact Me</Button>
        </MediaQuery>
        <MediaQuery minWidth={621} values={{ width: 621 }}>
          <Button onClick={this.renderContactForm}>Contact Me</Button>
          <BioContainer>
            <Title>{this.props.ownerName}</Title>
            <p>{this.props.ownerBio}</p>
          </BioContainer>
        </MediaQuery>
        <ContactFormPopUp hideForm={this.renderContactForm} {...popupProps} />
      </Container>
    );
  }
}

ContactForm.defaultProps = {
  postUrl: '',
  rooms: [],
  properties: [],
  email: '',
  departure: '',
  arrival: '',
  people: 1,
  name: '',
  ownerBio: '',
  ownerName: '',
};

ContactForm.propTypes = {
  rooms: PropTypes.arrayOf(PropTypes.any),
  properties: PropTypes.arrayOf(PropTypes.any),
  email: PropTypes.string,
  departure: PropTypes.string,
  arrival: PropTypes.string,
  people: PropTypes.number,
  postUrl: PropTypes.string,
  name: PropTypes.string,
  ownerBio: PropTypes.string,
  ownerName: PropTypes.string,
};

export default ContactForm;
