import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

import styles from './featuredProperties.scss';

const Link = styled.a`
  color: ${props => props.theme.palette.link || '#ff6b5a'};
  color: #333;
  font-weight: bold;
  text-decoration: none;
  margin: 0.5em auto;
  display: block;
`;

const Title = styled.h2`
  font-family: ${props => props.theme.headerFont.name || 'Caveat, cursive'};
`;

const FeaturedProperties = props => {
  if (props.items && props.items.length > 0) {
    return (
      <div className={styles.mainContainer}>
        <Title>{props.title}</Title>
        <div className={styles.featuredPropertiesGrid}>
          {props.items.map(item => (
            <div className={styles.featuredRow} key={item.propertyId}>
              <div
                role="button"
                tabIndex={0}
                className={styles.featured}
                onClick={() => {
                  // location.href = item.url;
                }}
              >
                <div className={styles.introItemImage}>
                  <img
                    src={item.mainImage.url}
                    srcSet={`
                      ${item.mainImage.url}?w=1540&mode=max&f=32 1540w,
                      ${item.mainImage.url}?w=1140&mode=max&f=32 1140w,
                      ${item.mainImage.url}?w=960&mode=max&f=32 960w,
                      ${item.mainImage.url}?w=768&mode=max&f=32 768w,
                      ${item.mainImage.url}?w=575&mode=max&f=32 575w,
                      ${item.mainImage.url}?w=375&mode=max&f=32 375w
                    `}
                    className="img-responsive"
                    alt={item.snippet}
                  />
                </div>
                <div className="title clearfix">
                  <div className={styles.pullLeft}>
                    <p className={styles.name}>
                      <Link href={item.url}>{item.name}</Link>
                    </p>
                    <p className={styles.place}>
                      {item.cityName}, {item.countryName}
                    </p>
                    <div className={styles.ratingBox}>
                      Needs to load the PropertyRating React Widget
                      {/* {% reactDeferred PropertyRating 0 'onReady' propertyId:item.property_id, hideOnEmpry:true  %} */}
                    </div>
                    <div className={styles.price}>
                      Needs to Load the PropertyPrices React Widget
                      {/* <div class="num-total">{% reactDeferred PropertyPrices 0 'onReady' propertyId:item.property_id %}</div> */}
                    </div>
                  </div>
                </div>
              </div>
            </div>
          ))}
        </div>
      </div>
    );
  }
  return null;
};

FeaturedProperties.defaultProps = {
  title: 'Featured Rentals',
  items: [],
};

FeaturedProperties.propTypes = {
  items: PropTypes.arrayOf(PropTypes.any),
  title: PropTypes.string,
};

export default FeaturedProperties;
