/* eslint-disable react/forbid-prop-types, no-return-assign, no-param-reassign */
import isNull from 'lodash/isNull';
import PropTypes from 'prop-types';
import React from 'react';
import jQuery from 'jquery';
import { formatImageUrl } from '@lodgify/utils';

const Fotorama = React.createClass({
  propTypes: {
    images: PropTypes.arrayOf(PropTypes.object),
    image_url: PropTypes.string,

    // images size
    imgWidth: PropTypes.number,
    imgHeight: PropTypes.number,

    // when fullscreen use that size
    fullImgWidth: PropTypes.number,
    fullImgHeight: PropTypes.number,

    // fotorama options (data-*)
    height: PropTypes.number,
    width: PropTypes.number,
    allowFullScreen: PropTypes.bool,
    ratio: PropTypes.string,
    fit: PropTypes.string,
    fitfull: PropTypes.string,
    nav: PropTypes.string,

    arrows: PropTypes.bool,
    autoPlay: PropTypes.bool,
  },

  getDefaultProps() {
    return {
      images: [],
      height: null,
      width: null,
      allowFullScreen: false,
      ratio: null,
      fit: 'contain',
      nav: 'dots',
      arrows: true,
      autoPlay: true,
    };
  },

  componentDidMount() {
    const domNode = this.node;

    if (isNull(domNode)) {
      // in case no images are informed, render returns null
      return false;
    }

    const node = domNode.children[0];
    const doCaptionFitsInParentBox = function doCaptionFitsInParentBox(
      $dotsWidth,
      $captionWidth,
      $parentBox,
    ) {
      return $dotsWidth + $captionWidth + 100 < $parentBox;
    };

    const handleCaptionText = (e, fotorama) => {
      const $node = jQuery(node);
      const dotsBoxWidth = $node.find('.fotorama__nav--dots').outerWidth();
      const dotsWidth = $node.find('.fotorama__nav__shaft').outerWidth();

      fotorama.$caption = fotorama.$caption || $node.next('.fotorama-caption');
      fotorama.$caption.text(fotorama.activeFrame.caption || '');
      const captionWidth = jQuery(fotorama.$caption).outerWidth();

      if (!doCaptionFitsInParentBox(dotsWidth, captionWidth, dotsBoxWidth)) {
        jQuery(fotorama.$caption).addClass('fotorama-caption-under-dots');
      } else {
        jQuery(fotorama.$caption).removeClass('fotorama-caption-under-dots');
      }
    };

    setTimeout(() => {
      jQuery(node)
        .on('fotorama:show', (e, fotorama) => {
          handleCaptionText(e, fotorama);
        })
        .on('fotorama:fullscreenenter fotorama:fullscreenexit', (e, fotorama) => {
          if (e.type === 'fotorama:fullscreenenter') {
            // Options for the fullscreen
            fotorama.setOptions({
              fit: this.props.fitfull,
            });
          } else {
            // Back to normal settings
            fotorama.setOptions({
              fit: this.props.fit,
            });
          }
        })
        .on('fotorama:showend', (e, fotorama) => {
          handleCaptionText(e, fotorama);
        })
        .fotorama();
    }, 300);

    return this;
  },

  componentWillUnmount() {
    const domNode = this.node;

    if (isNull(domNode)) {
      // in case no images are informed, render returns null
      return false;
    }

    if (domNode.children && domNode.children > 1) {
      const node = domNode.children[2];
      const fotoramaObject = jQuery(node).data('fotorama');
      fotoramaObject.destroy();
    }

    return this;
  },

  render() {
    if (!this.props.images || !this.props.images.length) {
      return null;
    }

    return (
      <div className="fotorama__wrapper" ref={node => this.node = node}>
        <div
          className="fotorama"
          data-auto="false"
          data-height={this.props.height}
          data-width={this.props.width}
          data-allow-full-screen={this.props.allowFullScreen}
          data-ratio={this.props.ratio}
          data-fit={this.props.fit}
          data-nav={this.props.nav}
          data-arrows={this.props.arrows}
          data-autoplay={this.props.autoPlay}
          data-images-quantity={this.props.images.length}
        >
          {this.props.images.map(img => (
            <a
              alt="Image"
              href={formatImageUrl(img.url, this.props.imgWidth, this.props.imgHeight, 'crop')}
              data-full={this.props.fullImgWidth &&formatImageUrl(img.url, this.props.fullImgWidth, this.props.fullImgHeight, 'max')}
              data-caption={img.text}
            >Image
            </a>
            ))}
        </div>
        <p className="fotorama-caption" />
      </div>
    );
  },
});

module.exports = Fotorama;
/* eslint-enable react/forbid-prop-types, no-return-assign, no-param-reassign */
