import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Gallery from 'react-photo-gallery';
import Lightbox from 'react-images';

import {
  I18nText,
  I18nPlainText
} from '../I18n';
import styles from './Gallery.scss';

class GalleryTabWidget extends Component {
  constructor(props) {
    super(props);
    this.state = { currentImage: 0 };
    this.closeLightbox = this.closeLightbox.bind(this);
    this.openLightbox = this.openLightbox.bind(this);
    this.gotoNext = this.gotoNext.bind(this);
    this.gotoPrevious = this.gotoPrevious.bind(this);
  }

  openLightbox(event, obj) {
    this.setState({
      currentImage: obj.index,
      lightboxIsOpen: true,
    });
  }
  closeLightbox() {
    this.setState({
      currentImage: 0,
      lightboxIsOpen: false,
    });
  }
  gotoPrevious() {
    this.setState({
      currentImage: this.state.currentImage - 1,
    });
  }
  gotoNext() {
    this.setState({
      currentImage: this.state.currentImage + 1,
    });
  }

  renderMaxPropertiesOne() {
    if (this.props.websiteMaxProperties === 1 && this.props.groups) {
      return this.props.groups.map(group => (
        <div key={group.title}>
          {this.props.images.map(image => {
            const srcSet = [
              `${image.url}?w=694&mode=max&f=32 472w`,
              `${image.url}?w=347&mode=max&f=32 236w`,
              `${image.url}?w=260&mode=max&f=32 260w`,
              `${image.url}?w=220&mode=max&f=32 220w`,
            ];
            const imageSet = [
              {
                src: image.url,
                width: image.width,
                height: image.height,
                srcSet,
              },
            ];

            return (
              <div key={image.text} className={`all ${group.title} ${styles.galleryContainer}`}>
                <Gallery
                  photos={imageSet}
                  srcSet={srcSet}
                  onClick={this.openLightbox}
                  margin={20}
                />
                <Lightbox
                  images={imageSet}
                  onClose={this.closeLightbox}
                  onClickPrev={this.gotoPrevious}
                  onClickNext={this.gotoNext}
                  currentImage={this.state.currentImage}
                  isOpen={this.state.lightboxIsOpen}
                />
              </div>
            );
          })}
        </div>
      ));
    }
    return null;
  }

  renderGallery() {
    this.srcSet = null;
    const imageSet = [];
    if (this.props.groups.map) {
      this.props.groups.map(group =>
        group.images.map(image => {
          const srcSet = [
            `${image.url}?w=694&mode=max&f=32 472w`,
            `${image.url}?w=347&mode=max&f=32 236w`,
            `${image.url}?w=260&mode=max&f=32 260w`,
            `${image.url}?w=220&mode=max&f=32 220w`,
          ];
          const img = {
            src: image.url,
            width: image.width,
            height: image.height,
            srcSet,
          };
          return imageSet.push(img);
          // let totalMorePicsNumber = 0;
          // totalMorePicsNumber += group.images.length;
        }),
      );
      return (
        <div className={styles.galleryContainer}>
          <Gallery photos={imageSet} srcSet={this.srcSet} onClick={this.openLightbox} />
          <Lightbox
            images={imageSet}
            onClose={this.closeLightbox}
            onClickPrev={this.gotoPrevious}
            onClickNext={this.gotoNext}
            currentImage={this.state.currentImage}
            isOpen={this.state.lightboxIsOpen}
          />
        </div>
      );
    }
    return null;
  }

  render() {
    if (this.props.groups) {
      return (
        <div id="Gallery">
          <section className="subtle-box">
            {this.props.groups.size > 1 ? (
              <div className="container">
                <div className={styles.row}>
                  <h5><I18nText keyName="TH_WI_GalleryTap_ViewPhotosFor" /></h5>
                </div>
                <div className={styles.row}>
                  <select id="gallery-select-room" className="form-control">
                    {this.props.groups.map((group, index) => (
                      //  slugify group.title
                      <option
                        key={group.title}
                        selected={index === 1 ? 'selected' : null}
                        value={index === 1 ? 'all' : group.title}
                      >
                        {index === 1 ? <I18nPlainText keyName="TH_WI_GalleryTab_AllPhotos" /> : group.title}
                      </option>
                    ))}
                  </select>
                </div>
              </div>
            ) : null}
            <div className={styles.row}>
              <div className="container">
                {this.renderMaxPropertiesOne()}
                {this.renderGallery()}
              </div>
            </div>
          </section>
        </div>
      );
    }
    return null;
  }
}

GalleryTabWidget.defaultProps = {
  groups: [],
  websiteMaxProperties: 1,
  images: [],
};

GalleryTabWidget.propTypes = {
  groups: PropTypes.arrayOf(PropTypes.any),
  websiteMaxProperties: PropTypes.number,
  images: PropTypes.arrayOf(PropTypes.any),
};

export default GalleryTabWidget;
