import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';

import I18nLoader from './I18nLoader';
import { ACTIONS as i18nActions } from '../../ducks/i18nTranslations';

/**
 * @param   {Object} props
 * @param   {Object} props.model
 * @param   {Object} props.pageId
 * @returns {Null}
 */
class I18nInitializer extends PureComponent {
  componentWillMount() {
    const { model, pageId, areCustomTranslationsLoaded } = this.props;
    const { culture, i18nJsUrl } = model;
    const { isoCode, shortCode } = culture;

    this.props.initializeI18n({ culture: { isoCode, shortCode }, i18nJsUrl, pageId });

    if (!areCustomTranslationsLoaded) {
      this.props.fetchCustomTranslations(pageId);
    }
  }

  componentWillUpdate(nextProps) {
    if (nextProps.pageId !== this.props.pageId) {

      const { model, pageId } = nextProps;
      const { culture, i18nJsUrl } = model;
      const { isoCode, shortCode } = culture;

      this.props.initializeI18n({ culture: { isoCode, shortCode }, i18nJsUrl, pageId });
      this.props.fetchCustomTranslations(pageId, shortCode);
    }
  }

  render() {
    const { model, updateTranslationsData, areTranslationsLoaded } = this.props;
    const { culture, i18nJsUrl: url } = model;
    const { isoCode } = culture;
    return (
      <I18nLoader
        url={url}
        isoCode={isoCode}
        areTranslationsLoaded={areTranslationsLoaded}
        onLoaded={updateTranslationsData}
      />
    );
  }
};

/**
 * @type {Object}
 */
I18nInitializer.propTypes = {
  model: PropTypes.shape({
    culture: PropTypes.shape({
      isoCode: PropTypes.string.isRequired,
      shortCode: PropTypes.string.isRequired
    }),
    i18nJsUrl: PropTypes.string.isRequired
  }).isRequired,
  pageId: PropTypes.number.isRequired,
  initializeI18n: PropTypes.func.isRequired,
  updateTranslationsData: PropTypes.func.isRequired,
  fetchCustomTranslations: PropTypes.func.isRequired,
  areTranslationsLoaded: PropTypes.bool.isRequired,
  areCustomTranslationsLoaded: PropTypes.bool.isRequired
};


function mapStateToProps(state) {
  const { i18n } = state.widgets;
  const {
    translations,
    customTranslations,
    areTranslationsLoaded,
    areCustomTranslationsLoaded
  } = i18n;

  return {
    translations,
    customTranslations,
    areTranslationsLoaded,
    areCustomTranslationsLoaded
  };
}

function mapDispatchToProps(dispatch) {
  return {
    initializeI18n: data => {
      dispatch(i18nActions.initialize(data));
    },
    updateTranslationsData: () => {
      dispatch(i18nActions.updateTranslationsData(global.ldgfy_i18n_json));
    },
    fetchCustomTranslations: (pageId, shortCode) => {
      dispatch(i18nActions.fetchCustomTranslations(pageId, shortCode));
    }
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(I18nInitializer);
