import React from 'react';
import PropTypes from 'prop-types';

import { Dependenceees } from '@lodgify/dependenceees';

/**
 * @param   {Object} props
 * @param   {Object} props.model
 * @returns {Object}
 */
const I18nLoader = ({ url, isoCode, onLoaded, areTranslationsLoaded, children }) => {
  const encodedUrl = url.replace('xxxx', isoCode);
  return (
    <Dependenceees
      onLoaded={onLoaded}
      scripts={[{
        src: encodedUrl,
        id: 'i18n-legacy-file',
        check: () => areTranslationsLoaded
      }]}
    >
      { children }
    </Dependenceees>
  );
};

I18nLoader.defaultProps = {
  children: null
};

/**
 * @type {Object}
 */
I18nLoader.propTypes = {
  areTranslationsLoaded: PropTypes.bool.isRequired,
  url: PropTypes.string.isRequired,
  onLoaded: PropTypes.func.isRequired,
  isoCode: PropTypes.string.isRequired,
  children: PropTypes.oneOfType([
    PropTypes.element,
    PropTypes.array,
    PropTypes.node,
  ]),
};

export default I18nLoader;
