import { connect } from 'react-redux';
import PropTypes from 'prop-types';
import { translate } from './translate';

const I18nText = (props) => {
  const {
    keyName,
    quantity,
    pluralKeyName,
    isI18nInitialized,
    areTranslationsLoaded,
    translations,
    customTranslations,
    culture,
    values
  } = props;

  if (!isI18nInitialized) {
    const errorMessage = '<I18nInitializer /> hasn\'t been bootstrapped correctly.';

    console.error(errorMessage);
    throw new Error(errorMessage);
  }

  if (!areTranslationsLoaded) {
    return keyName;
  }

  const { shortCode } = culture;

  return translate(
    translations,
    customTranslations,
    shortCode,
    keyName,
    pluralKeyName,
    quantity,
    values
  );
};

I18nText.defaultProps = {
  className: '',
  pluralKeyName: '',
  quantity: 0,
  values: []
};

I18nText.propTypes = {
  keyName: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.arrayOf(PropTypes.string)
  ]).isRequired,
  translations: PropTypes.shape({}).isRequired,
  customTranslations: PropTypes.shape({}).isRequired,
  culture: PropTypes.shape({
    isoCode: PropTypes.string.isRequired,
    shortCode: PropTypes.string.isRequired
  }).isRequired,
  isI18nInitialized: PropTypes.bool.isRequired,
  areTranslationsLoaded: PropTypes.bool.isRequired,
  pluralKeyName: PropTypes.string,
  quantity: PropTypes.number,
  values: PropTypes.arrayOf(PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.number
  ]))
};

function mapStateToProps(state) {
  const { i18n } = state.widgets;
  const {
    areTranslationsLoaded,
    translations,
    customTranslations,
    culture,
    isI18nInitialized
  } = i18n;

  return {
    areTranslationsLoaded,
    translations,
    culture,
    customTranslations,
    isI18nInitialized
  };
}

export default connect(mapStateToProps)(I18nText);
