import React, { Component } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import { withScriptjs, withGoogleMap, GoogleMap, Marker } from 'react-google-maps';

import {
  I18nText
} from '../I18n';
import styles from './MapTab.scss';

const LocationTitle = styled.h2`
  font-family: ${props => props.theme.headerFont.name || 'Caveat'};
  font-size: ${props => 25 / props.theme.bodyFont.size}rem;
`;

function renderDirectionText(text) {
  return { __html: text };
}

const Map = withScriptjs(
  withGoogleMap(props => (
    <GoogleMap defaultZoom={16} defaultCenter={{ lat: props.latitude, lng: props.longitude }}>
      <Marker position={{ lat: props.latitude, lng: props.longitude }} />
    </GoogleMap>
  )),
);

class MapTabWidget extends Component {
  constructor(props) {
    super(props);
    this.getDistance = this.getDistance.bind(this);
  }

  /* eslint-disable */
  getDistance(distance) {
    let data = {
      title: '',
      icon: '',
    };
    switch (distance.id) {
      case 'train':
        data = {
          title: 'G_Train',
          icon: 'icon-train',
        };
        break;
      case 'airport':
        data = {
          title: 'G_Airport',
          icon: 'icon-plane',
        };
        break;
      case 'bus':
        data = {
          title: 'G_Bus',
          icon: 'icon-bus2',
        };
        break;
      case 'motorway':
        data = {
          title: 'G_Motorway',
          icon: 'icon-road',
        };
        break;
      case 'port':
        data = {
          title: 'G_Port',
          icon: 'icon-ship2',
        };
        break;
      case 'underground':
        data = {
          title: 'G_Underground',
          icon: 'icon-uni55',
        };
        break;
      default:
        return data;
    }
    return data;
  }
  /* eslint-enable */

  render() {
    return (
      <div className={`${styles.container} house-map`} id="Map">
        {!this.props.hideAddress && this.props.distances.length > 0 && this.props.directions ? (
          <section className="subtle-box">
            {!this.props.hideAddress ? (
              <div className={styles.location}>
                <div className="row">
                  <LocationTitle theme={this.props.theme}>
                    <I18nText keyName="G_Location" />
                  </LocationTitle>
                  <p className={styles.address}>
                    {this.props.address}, {this.props.cityName}, {this.props.zip},
                    {this.props.countryName}
                  </p>
                </div>
                {this.props.directions ? (
                  <div className={styles.container}>
                    <div className={styles.row}>
                      <div
                        className={styles.drections}
                        dangerouslySetInnerHTML={renderDirectionText(this.props.directions)}
                      />
                    </div>
                  </div>
                ) : null}
              </div>
            ) : null}

            {this.props.locationImage &&
              this.props.locationImage.url && (
                <div className="container">
                  <div className={styles.row}>
                    <div className="title"><I18nText keyName="TH_WI_MapTap_CustomMap" /></div>
                    <div>
                      <a
                        className={styles.mapImageWrapper}
                        href={this.props.locationImage}
                        rel="lightbox"
                      >
                        <img
                          className="map-tab__location-image"
                          src={this.props.locationImage}
                          alt={this.props.locationImage}
                          srcSet="{{this.props.location_image | image_url:300,0,'full'}} 2x, {{this.props.location_image | image_url:960,0,'full'}}"
                        />
                      </a>
                    </div>
                  </div>
                </div>
              )}
            <div
              className="hidden"
              data-require-initialization="widget"
              data-widget-name="map-tab"
              data-widget-id="{{this.props.id}}"
              data-widget-approximated={
                this.props.websiteOptions.includes('ShowDotOfPropertyInMaps') ? 'true' : 'false'
              }
            >
              <div
                data-widget-data="map-tab"
                data-map-latitude="{{this.props.latitude}}"
                data-map-longitude="{{this.props.longitude}}"
                data-map-approximated="{{this.props.hide_address}}"
              />
            </div>
          </section>
        ) : null}
        {this.props.latitude && this.props.longitude ? (
          <section>
            <Map
              isMarkerShown
              latitude={this.props.latitude}
              longitude={this.props.longitude}
              googleMapURL="https://maps.googleapis.com/maps/api/js?v=3.exp&libraries=geometry,drawing,places"
              loadingElement={<div style={{ height: `100%` }} />}
              containerElement={<div style={{ height: `400px` }} />}
              mapElement={<div style={{ height: `100%` }} />}
            />
            {this.props.distances.length > 0 ? (
              <div className={styles.container}>
                <div className={styles.row}>
                  <div className={styles.distancesList}>
                    {this.props.distances.map(distance => (
                      <div key={distance.id} className={styles.distanceItem}>
                        <span className={`${this.getDistance(distance).icon} ${styles.icon}`} />
                        <div className={styles.distanceText}>
                          {/* {this.getDistance(distance).title} */}
                          <span className={styles.distanceValue}>
                            {/* | distance */}
                            {distance.value} &nbsp;
                          </span>
                          {/* {this.props.distanceUnit === 'km' ? (
                            <a
                                title={<I18nPlainText keyName="G_OtherUnits" />}: {{distance.value | to_miles | distance }} <I18nPlainText keyName="G_Unit_miles" />}
                                rel="tooltip"
                              >
                                <i className="icon-question-circle" />
                              </a>

                            ) : (
                              <a
                                title={<I18nPlainText keyName="G_OtherUnits" />}: {{distance.value | to_km | distance }} <I18nPlainText keyName="G_Unit_km" />}
                                rel="tooltip"
                              >
                                <i className="icon-question-circle" />
                              </a>
                              */}
                          {/* <p>{this.getDistance(distance).title}</p> */}
                        </div>
                      </div>
                    ))}
                  </div>
                </div>
              </div>
            ) : null}
          </section>
        ) : null}
      </div>
    );
  }
}

MapTabWidget.defaultProps = {
  websiteOptions: '',
  address: 'Carrer Arago Barcelona',
  countryName: 'Spain',
  distances: [],
  cityName: '',
  zip: '',
  hideAddress: false,
  directions: '',
  locationImage: {},
  latitude: 41.3947688,
  longitude: 2.0787283,
  theme: {},
};

MapTabWidget.propTypes = {
  websiteOptions: PropTypes.string,
  address: PropTypes.string,
  countryName: PropTypes.string,
  distances: PropTypes.arrayOf(PropTypes.any),
  // distanceUnit: PropTypes.string,
  cityName: PropTypes.string,
  zip: PropTypes.string,
  hideAddress: PropTypes.bool,
  directions: PropTypes.string,
  locationImage: PropTypes.objectOf(PropTypes.any),
  latitude: PropTypes.number,
  longitude: PropTypes.number,
  theme: PropTypes.objectOf(PropTypes.any),
};

export default MapTabWidget;
