import React, { Component } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import { OVERVIEW } from '../../../utils/constants';

import {
  I18nText
} from '../I18n';
import styles from './Overview.scss';
import { renderKeyFactsIcons } from '../../../utils';

const Title = styled.h2`
  margin: 1em 0;
  font-family: ${props => props.theme.headerFont.name || 'Caveat'};
  font-size: ${props => 35 / props.theme.bodyFont.size}rem;
  flex: 1 1 100%;
  min-width: 100%;

  @media screen and (max-width: 620px) {
    font-size: 1.5rem;
  }
`;

// TODO to be moved in to a utils file
const replaceCommaWithLine = text =>
  text.split(',').map(t => (
    <span key={t} className={styles.featureGroupText}>
      {t}
    </span>
  ));

export default class OverviewTab extends Component {
  constructor(props) {
    super(props);
    this.state = {};
  }

  setDescription() {
    return { __html: this.props.description };
  }

  renderFeatureGroup() {
    const room = this.props.rooms[0];
    return (
      room.featureGroups &&
      room.featureGroups.map(featureGroup => {
        if (!featureGroup.id === 'room') {
          return '';
        }

        return room.features.map(feature => {
          let first = true;
          if (featureGroup.text.includes(feature.text) && !first) {
            first = false;
            return feature.text;
          }
          return '';
        });
      })
    );
  }

  renderKeyFacts() {
    const room = this.props.rooms[0] || [];
    const keyFactsArr = [
      'EntertainmentInternet',
      'HeatingACAirConditioning',
      'SpaOutdoorSwimmingPool',
    ];
    return (
      <ul className={styles.list}>
        <li data-room-details-icon="users" className={styles.keyFactsListItem}>
          <i className={`icon-users2 ${styles.keyIcon}`} />&nbsp; {this.props.rooms[0].maxPeople}
        </li>
        {this.props.rooms[0].areaIsSquareMeters ? (
          <li data-room-details-icon="sqm" className={styles.keyFactsListItem}>
            <small><I18nText keyName="TH_UnitSqmShort" /></small>&nbsp;{this.props.rooms[0].maxArea}
          </li>
        ) : (
          <li data-room-details-icon="sqf" className={styles.keyFactsListItem}>
            <small><I18nText keyName="TH_UnitSqfShort" /></small>&nbsp;{this.props.rooms[0].maxArea}
          </li>
        )}
        {room.features.map(
          feature =>
            keyFactsArr.indexOf(feature.name) > 0 ? (
              <li
                key={feature.name}
                data-room-details-icon={renderKeyFactsIcons(feature).roomIcon}
                className={styles.listkeyFactsListItemItem}
              >
                <i className={`${renderKeyFactsIcons(feature).icon} ${styles.keyIcon}`} />&nbsp;{' '}
                {feature.prefix}
              </li>
            ) : null,
        )}
      </ul>
    );
  }

  renderFeatureGroupArray() {
    return (
      this.props.rooms[0].featureGroups &&
      this.props.rooms[0].featureGroups.map(
        featureGroup =>
          OVERVIEW.featuredGroupArray.indexOf(featureGroup.id) !== -1 && (
            <li key={featureGroup.id} className={styles.listItem}>
              <p className={styles.featureListItem}>
                <span
                  className={`${OVERVIEW.featureGroupsMetadata[featureGroup.id].iconName} ${
                    styles.overviewIcon
                  }`}
                />
                <span>
                  <span className={styles.featureGroupTitle}>
                    <I18nText keyName={OVERVIEW.featureGroupsMetadata[featureGroup.id].i18nKey} />{' '}
                  </span>
                  {replaceCommaWithLine(featureGroup.text)}
                </span>
              </p>
            </li>
          ),
      )
    );
  }

  renderPoliciesFeature() {
    return (
      <section className="subtle-box overview-tab__policies">
        <div className={styles.row}>
          <Title><I18nText keyName="TH_WI_OverviewTab_Policies" /></Title>
          {this.props.featureGroups.map(
            featureGroup =>
              featureGroup.id === 'policies' ? (
                <span key={featureGroup.id}>{featureGroup.text}</span>
              ) : null,
          )}
          <div className={styles.row}>
            {this.props.checkIn ? (
              <div className={styles.checkIn}>
                <p className={styles.flexed}>
                  {/* Filter by hour | hour */}
                  <span className={`${styles.icon} icon-enter-right`} />
                  <span className={styles.checkContainer}>
                    <span className={styles.checkinTitle}><I18nText keyName="TH_CheckIn" />: </span>
                    <span className={styles.checkInText}>{this.props.checkIn} </span>
                  </span>
                </p>
              </div>
            ) : null}
            {this.props.checkOut ? (
              <div className={styles.checkOut}>
                {/* Filter by hour | hour */}
                <p className={styles.flexed}>
                  <span className={`${styles.icon} icon-exit-left`} />
                  <span className={styles.checkContainer}>
                    <span className={styles.checkOutTitle}><I18nText keyName="TH_CheckIn" />: </span>
                    <span className={styles.checkcheckOutTextInText}>{this.props.checkOut} </span>
                  </span>
                </p>
              </div>
            ) : null}
          </div>
        </div>
      </section>
    );
  }

  renderFacilities() {
    return (
      <section id={'facilities'} className={`${styles.subtleBox}`}>
        <div className={styles.row}>
          <Title><I18nText keyName="TH_WI_OverviewTab_Facilities" /></Title>
          <div className={styles.viewMore}>
            {this.props.featureGroups.map(
              feature =>
                feature.id === 'general' ? <span key={feature.id}>{feature.text}</span> : null,
            )}
            <div className={styles.list}>
              {this.props.featureGroups.map(
                featureGroup =>
                  featureGroup.id === 'general'
                    ? OVERVIEW.featuredGroupArray.indexOf(featureGroup.id) !== -1 && (
                    <span key={featureGroup.id}>
                      <span className={OVERVIEW.facilitiesMetadata[featureGroup.id].iconName} />
                      <I18nText keyName={OVERVIEW.facilitiesMetadata[featureGroup.id].i18nKey} />
                    </span>
                      )
                    : null,
              )}
            </div>
          </div>
        </div>
      </section>
    );
  }

  render() {
    return (
      <div className="house-overview" id="Overview">
        <section className={styles.subtleBox}>
          <div className={styles.mainContainer}>
            {this.props.rooms.length > 0 ? (
              <div className={styles.container}>
                <div className={styles.row}>
                  {/* <Title><I18nText keyName="TH_WI_OverviewTab_Keyfacts" /></Title> */}
                  {this.renderKeyFacts()}
                </div>

                <div className={styles.row}>
                  <Title><I18nText keyName="TH_WI_OverviewTab_Description" /></Title>
                  <div
                    className={styles.viewMore}
                    dangerouslySetInnerHTML={this.setDescription()}
                  />
                </div>
                <div className={styles.row}>
                  <Title><I18nText keyName="G_Amenities" /></Title>
                  <ul className={styles.featureList}>{this.renderFeatureGroupArray()}</ul>
                </div>
                <div className={styles.row}>{this.renderFacilities()}</div>
                <div className={styles.row}>{this.renderPoliciesFeature()}</div>
                <div className={styles.row}>
                  <Title><I18nText keyName="G_Rooms" /></Title>
                  <div className={''}>{this.renderFeatureGroup()}</div>
                </div>

                {this.props.rooms.size > 1 ? (
                  <section id="rooms-section" className="rooms-section">
                    {this.props.rooms.map(room => (
                      <div className="room-card-box" key={room.id}>
                        {'reactDeferred BookingRoom'}
                        {/* {% reactDeferred BookingRoom 0 "onReady" propertyId:global.property_id, roomId:room.id %} */}
                        {/* {% comment %}{% use "snippets/room_card" with room -%}{% endcomment %} */}
                      </div>
                    ))}
                  </section>
                ) : null}
                <div id="data-rooms-size" className="hidden" data-size={this.props.rooms.size} />
              </div>
            ) : null}
            {this.props.rooms.size > 1 ? (
              <section id="rooms-section" className="rooms-section">
                {this.props.rooms.map(room => (
                  <div className="room-card-box" key={room.id}>
                    {'reactDeferred BookingRoom'}
                    {/* {% reactDeferred BookingRoom 0 "onReady" propertyId:global.property_id, roomId:room.id %} */}
                    {/* {% comment %}{% use "snippets/room_card" with room -%}{% endcomment %} */}
                  </div>
                ))}
              </section>
            ) : null}
            <div id="data-rooms-size" className="hidden" data-size={this.props.rooms.size} />
          </div>
        </section>
      </div>
    );
  }
}

OverviewTab.defaultProps = {
  rooms: [],
  featureGroups: [],
  description: '',
  theme: {},
  websiteMaxProperties: 1,
  checkIn: false,
  checkOut: false,
};

OverviewTab.propTypes = {
  rooms: PropTypes.arrayOf(PropTypes.any),
  featureGroups: PropTypes.arrayOf(PropTypes.any),
  description: PropTypes.string,
  theme: PropTypes.objectOf(PropTypes.any),
  websiteMaxProperties: PropTypes.number,
  checkIn: PropTypes.bool,
  checkOut: PropTypes.bool,
};
