/* eslint-disable jsx-a11y/tabindex-no-positive */
import React from 'react';
import styled from 'styled-components';
import PropTypes from 'prop-types';

import {
  I18nText,
  I18nPlainText
} from '../I18n';
import styles from './ownerSignup.scss';

const Title = styled.h2`
  font-family: ${props => props.theme.headerFont.name || 'Caveat, cursive'};
`;

const Button = styled.button`
  background: ${props => props.theme.palette.action || '#fac600'};
  border-radius: 40px;
  font-size: 0.75rem;
  border: none;
  width: 140px;
  height: 40px;
`;

const OwnerSignup = props => (
  <section className={`${styles.subtleBox} ${styles.owner}`}>
    <div className="container">
      <form
        action={props.postUrl}
        className="signup-form"
        id="signup-form"
        method="post"
        data-ajax="true"
        data-ajax-method="POST"
        data-ajax-begin="ldgfy.signup.onBeforeSignup"
        data-ajax-failure="ldgfy.signup.onErrorSignup"
        data-ajax-success="ldgfy.signup.onSuccessSignup"
      >
        <div className="row">
          <div className="col-md-12">
            <Title><I18nText keyName="TH_Signup" /></Title>
          </div>
        </div>
        <div className="row">
          <div className="col-md-12">
            <div
              id="signup-ok"
              className={`${styles.alert} alert-success`}
              style={{ display: 'none' }}
            >
              <span><I18nText keyName="TH_WI_OwnerSignup_SignupOk" /></span>
            </div>

            <div
              id="signup-ko"
              className={`${styles.alert} alert-danger`}
              style={{ display: 'none' }}
            >
              <span><I18nText keyName="TH_WI_OwnerSignup_SignupKo" /></span>
            </div>

            <div
              className={`${styles.alert} validation-summary-valid alert-danger`}
              data-valmsg-summary="true"
              id="signup-validation-summary"
            >
              <ul>
                <li style={{ display: 'none' }} />
              </ul>
            </div>
          </div>
        </div>
        <div className="row">
          <div className="col-md-12">
            <div className="form-group">
              <input
                id="FirstName"
                name="FirstName"
                className="form-control"
                tabIndex="201"
                data-val="true"
                data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'TH_WI_OwnerSignup_FirstName']} />}
                placeholder={<I18nPlainText keyName="TH_WI_OwnerSignup_FirstName" />}
                type="text"
                defaultValue=""
              />
            </div>
          </div>
        </div>
        <div className="row">
          <div className="col-md-12">
            <div className="form-group">
              <input
                id="LastName"
                name="LastName"
                tabIndex="202"
                className="form-control"
                data-val="true"
                data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'TH_WI_OwnerSignup_LastName' ]} />}
                placeholder={<I18nPlainText keyName="TH_WI_OwnerSignup_LastName" />}
                type="text"
                value=""
              />
            </div>
          </div>
        </div>
        <div className="row">
          <div className="col-md-12">
            <div className="form-group">
              <input
                id="Email"
                name="Email"
                tabIndex="203"
                className="form-control"
                data-val="true"
                data-val-email={<I18nPlainText keyName={['G_Error_EmailNotValid', 'TH_WI_OwnerSignup_Email' ]} />}
                data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'TH_WI_OwnerSignup_Email' ]} />}
                placeholder={<I18nPlainText keyName="TH_WI_OwnerSignup_Email" />}
                type="text"
                defaultValue=""
              />
            </div>
          </div>
        </div>
        <div className="row">
          <div className="col-md-12">
            <div className="form-group">
              <Button id="login-send" type="submit" tabIndex="204">
                <I18nText keyName="G_Button_Send" />
              </Button>
            </div>
          </div>
        </div>
      </form>
    </div>
  </section>
);

OwnerSignup.defaultProps = {
  postUrl: '',
};

OwnerSignup.propTypes = {
  postUrl: PropTypes.string,
};

export default OwnerSignup;
