import React, { Component } from 'react';
import PropTypes from 'prop-types';
import jQuery from 'jquery';

import {
  I18nText,
  I18nPlainText
} from '../I18n';

class RatesTabWidget extends Component {
  constructor(props) {
    super(props);
    this.rowsNum = props.hasWeekDayRate || props.hasPerPersonExtraCharge ? 2 : 1;
    this.selectRatesRoom = this.selectRatesRoom.bind(this);
  }

  componentDidMount() {
    if (
      global.ReadMore &&
      global.ReadMore.refresh &&
      typeof global.ReadMore.refresh === 'function'
    ) {
      global.ReadMore.refresh();
    }
    this.selectRatesRoom();
  }

  /* eslint-disable */
  getPrice(price, rate) {
    switch (price.days[0]) {
      case 'monday':
        return rate.mondayPrice;
      case 'tuesday':
        return rate.tuesdayPrice;
      case 'wednesday':
        return rate.wednesdayPrice;
      case 'thursday':
        return rate.thursdayPrice;
      case 'friday':
        return rate.fridayPrice;
      case 'saturday':
        return rate.saturdayPrice;
      case 'sunday':
        return rate.sundayPrice;
      default:
        return 0;
    }
  }

  selectRatesRoom(e) {
    if (e) {
      if (
        global.ReadMore &&
        global.ReadMore.refresh &&
        typeof global.ReadMore.refresh === 'function'
      ) {
        global.ReadMore.refresh();
      }

      jQuery('#rates-select-room').on('change', () => {
        let v = jQuery('#rates-select-room').val() || '{{model.rooms[0].id}}';
        if (jQuery('#rates-select-room').val() == 'all') v = '{{model.rooms[0].id}}';

        if (!$.fn.velocity) {
          console.error('No velocity jQuery plugin installed');
        }

        // jQuery('.table-rates').velocity('transition.slideUpOut', {
        //   duration: 300,
        //   complete() {
        //     jQuery(`.table-rates.table-rates--${v}`).velocity('transition.slideDownIn', {
        //       duration: 300,
        //     });
        //   },
        // });
      });

      let v = jQuery('#rates-select-room').val() || '{{model.rooms[0].id}}';
      if (jQuery('#rates-select-room').val() == 'all') v = '{{model.rooms[0].id}}';

      // jQuery('.table-rates').velocity('transition.slideUpOut', {
      //   duration: 300,
      //   complete() {
      //     jQuery(`.table-rates.table-rates--${v}`).velocity('transition.slideDownIn', {
      //       duration: 300,
      //     });
      //   },
      // });

      jQuery('#rates-select-room').trigger('change');

      jQuery('#radio-price').on('change', () => {
        if (jQuery('#radio-price').val() == 'payment') {
          jQuery('.payment-prices').removeClass('hide');
          jQuery('.user-prices').addClass('hide');
        } else if (jQuery('#radio-price').val() == 'user') {
          jQuery('.user-prices').removeClass('hide');
          jQuery('.payment-prices').addClass('hide');
        }
      });
    }
    jQuery('.navbar').addClass('solid');
    global.ldgfy && jQuery(document).bind(global.ldgfy.EVENTS.RELOAD_PRICES, formatUserCurrency);
    global.ldgfy && jQuery(document).trigger(global.ldgfy.EVENTS.RELOAD_PRICES);
  }
  /* eslint-enable */
  renderExternal() {
    if (this.props.isExternal) {
      return <h4><I18nText keyName="TH_WI_RatesTab_HouseUsesExternalRates" /></h4>;
    }
    if (this.props.rooms.length > 1) {
      return (
        <div className="container">
          <div className="row">
            <div className="col-sm-6 col-xs-12 select-room-title">
              <h5><I18nText keyName="TH_WI_RatesTap_ViewRatesFor" /></h5>
            </div>
            <div className="col-sm-4 col-xs-12">
              <select id="rates-select-room" className="form-control">
                {this.props.rooms.map(room => (
                  <option key={room.id} value={room.id}>
                    {room.name}
                  </option>
                ))}
              </select>
            </div>
          </div>
          <hr style={{ marginBottom: '0px !important' }} />
        </div>
      );
    }
    return null;
  }
  renderDailyRateTh() {
    if (this.props.hasDailyRate) {
      if (this.rowsNum === 2 && this.props.hasWeekdayRate) {
        return this.props.weekdayPrices.map(price => <th key={price.caption}>{price.caption}</th>);
      }
      return (
        <th className="upcase" rowSpan="{{this.rowsNum}}">
          <I18nText keyName="G_Rates_Daily" />
        </th>
      );
    }
    return null;
  }
  renderHasNoSeasons(room) {
    if (!this.props.hasSeasons) {
      return room.rates.map(rate => (
        <tr key={rate.name}>
          <td>
            {this.props.showRateName ? <div className="rate-title">{rate.name}</div> : null}
            {this.props.hasPerPersonExtraCharge ? (
              <div className="rate-details">
                <div>
                  {/* <!--data-title={<I18nPlainText keyName="G_PriceFor" />}--> */}
                  <i className="icon-users2" />
                  {rate.perPersonAppliesToOrDefault} <I18nText keyName="G_People" />
                </div>
                <div>
                  {/* <!--data-title="Charge per extra person"--> */}
                  {rate.perPersonExtraChargeOrDefault > 0 ? (
                    <span>
                      <span className="payment-prices">
                        {/* | money_with_currency:this.props.currency */}
                        <span>{rate.perPersonExtraChargeOrDefault}</span>
                      </span>
                      <span className="user-prices hide">
                        <span data-price="{{rate.per_person_extra_charge_or_default | divided_by: this.props.currency.conversion }}" />
                      </span>
                      \/ <I18nText keyName="TH_NightExtraPer" />
                    </span>
                  ) : null}
                </div>
              </div>
            ) : null}
          </td>
          {this.props.hasDailyRate && this.props.hasWeekdayRate && rate.isWeekdayRate ? (
            this.props.weekdayPrices.map(price => (
              <td data-title="{{price.caption}}" key={price}>
                {this.getPrice(price, rate) > 0 ? (
                  <span>
                    <span className="payment-prices">
                      {/* | money_with_currency:this.props.currency */}
                      <span>{this.getPrice(price, rate)}</span>
                    </span>
                    <span className="user-prices hide">
                      {/* | divided_by: this.props.currency.conversion */}
                      <span data-price={this.getPrice(price, rate)} />
                    </span>
                  </span>
                ) : (
                  <span>
                    <span className="payment-prices">-</span>
                  </span>
                )}
              </td>
            ))
          ) : (
            <td
              data-title={<I18nPlainText keyName="G_Rates_Daily" />}
              colSpan={this.props.hasWeekdayRate ? this.props.weekdayPrices.size : null}
              style={{ textAlign: 'center' }}
            >
              {rate.hideDailyPrice && rate.dailyPrice > 0 ? (
                <span>
                  <span className="payment-prices">
                    {/* | money_with_currency:this.props.currency */}
                    <span>{rate.dailyPrice}</span>
                  </span>
                  <span className="user-prices hide">
                    <span data-price="{{rate.daily_price | divided_by: this.props.currency.conversion}}" />
                  </span>
                </span>
              ) : (
                <span>
                  <span className="payment-prices">-</span>
                </span>
              )}
            </td>
          )}
          {this.props.hasWeeklyRate ? (
            <td data-title={<I18nPlainText keyName="G_Rates_Weekly" />}>
              {rate.weeklyPrice && rate.weeklyPrice ? (
                <span>
                  <span className="payment-prices">
                    {/* | money_with_currency:this.props.currency */}
                    <span>{rate.weeklyPrice}</span>
                  </span>
                  <span className="user-prices hide">
                    {/* | divided_by: this.props.currency.conversion */}
                    <span data-price={rate.weekly_price} />
                  </span>
                </span>
              ) : (
                <span>
                  <span className="payment-prices">-</span>
                </span>
              )}
            </td>
          ) : null}

          {this.props.hasMonthlyRate ? (
            <td data-title={<I18nPlainText keyName="G_Rates_Monthly" />}>
              {rate.monthlyPrice && rate.monthlyPrice > 0 ? (
                <span>
                  <span className="payment-prices">
                    {/* | money_with_currency:this.props.currency */}
                    <span>{rate.monthlyPrice}</span>
                  </span>
                  <span className="user-prices hide">
                    <span data-price="{{rate.monthly_price | divided_by: this.props.currency.conversion}}" />
                  </span>
                </span>
              ) : (
                <span>
                  <span className="payment-prices">-</span>
                </span>
              )}
            </td>
          ) : null}
          {this.props.customRateDays > 0 ? (
            <td data-title={this.props.custom_rate_days + (<I18nPlainText keyName="G_Rates_UnitDays" />)}>
              {rate.custom_price && rate.customPrice > 0 ? (
                <span>
                  <span className="payment-prices">
                    {/* | money_with_currency:this.props.currency */}
                    <span>{rate.customPrice}</span>
                  </span>
                  <span className="user-prices hide">
                    {/* | divided_by: this.props.currency.conversion */}
                    <span data-price={rate.customPrice} />
                  </span>
                </span>
              ) : (
                <span>
                  <span className="payment-prices">-</span>
                </span>
              )}
            </td>
          ) : null}
        </tr>
      ));
    }
    return null;
  }
  renderHasDailyRates(rate) {
    if (this.props.hasDailyRate) {
      if (this.props.hasWeekDayRate && rate.isWeekdayRate) {
        return this.props.weekdayPrices.map(price => (
          <td data-title={price.caption} key={price.caption}>
            {this.getPrice(price, rate) > 0 ? (
              <span>
                <span className="payment-prices">
                  {/* | money_with_currency:this.props.currency */}
                  <span>{this.getPrice(price, rate)}</span>
                </span>
                <span className="user-prices hide">
                  {/* | divided_by: this.props.currency.conversion */}
                  <span data-price={this.getPrice(price, rate)} />
                </span>
              </span>
            ) : (
              <span>
                <span className="payment-prices">-</span>
              </span>
            )}
          </td>
        ));
      }
    } else {
      return (
        <td
          data-title={<I18nPlainText keyName="G_Rates_Daily" />}
          colSpan={this.props.hasWeekdayRate ? this.props.weekdayPrices.size : null}
          style={{ textAlign: 'center' }}
        >
          {!rate.hideDailyPrice && rate.dailyPrice > 0 ? (
            <span>
              <span className="payment-prices">
                {/* | money_with_currency:this.props.currency */}
                <span>{rate.dailyPrice}</span>
              </span>
              <span className="user-prices hide">
                <span data-price="{{rate.daily_price | divided_by: this.props.currency.conversion}}" />
              </span>
            </span>
          ) : (
            <span>
              <span className="payment-prices">-</span>
            </span>
          )}
        </td>
      );
    }
    return null;
  }
  renderTbody(room) {
    return this.props.periods.map(period =>
      room.rates.map(rate => {
        if (period.rate.name === rate.name) {
          return (
            <tr key={period}>
              <td>
                {this.props.hasSeasons && this.props.showRateName ? (
                  <div>
                    <div className="rate-title">{period.rate.name}</div>

                    {/* <div className="rate-period">{{period.start | short_date }} - {{period.end | short_date }}</div> */}
                    <div className="rate-period">
                      {period.start} - {period.end}
                    </div>
                  </div>
                ) : null}
                {this.props.hasPerPersonExtraCharge ? (
                  <div className="rate-details">
                    <div>
                      {/* <!--data-title={<I18nPlainText keyName="G_PriceFor" />}--> */}
                      <i className="icon-users2" />
                      {rate.perPersonAppliesToOrDefault} <I18nText keyName="G_People" />
                    </div>
                    <div>
                      {/* }<!--data-title="Charge per extra person"--> */}
                      {rate.perPersonExtraChargeOrDefault > 0 ? (
                        <span>
                          <span className="payment-prices">
                            {/* | money_with_currency:this.props.currency */}
                            <span>{rate.perPersonExtraChargeOrDefault}</span>
                          </span>
                          <span className="user-prices hide">
                            {/* | divided_by: this.props.currency.conversion */}
                            <span data-price={rate.perPersonExtraChargeOrDefault} />
                          </span>
                          \/ <I18nText keyName="TH_NightExtraPer" />
                        </span>
                      ) : null}
                    </div>
                  </div>
                ) : null}
              </td>
              {this.renderHasDailyRates(rate)}
              {this.props.hasWeeklyRate ? (
                <td data-title={<I18nPlainText keyName="G_Rates_Weekly" />}>
                  {rate.weeklyPrice && rate.weeklyPrice > 0 ? (
                    <span>
                      <span className="payment-prices">
                        {/* | money_with_currency:this.props.currency */}
                        <span>{rate.weeklyrice}</span>
                      </span>
                      <span className="user-prices hide">
                        <span data-price="{{rate.weekly_price | divided_by: this.props.currency.conversion}}" />
                      </span>
                    </span>
                  ) : (
                    <span>
                      <span className="payment-prices">-</span>
                    </span>
                  )}
                </td>
              ) : null}
              {this.props.hasMonthlyRate ? (
                <td data-title={<I18nPlainText keyName="G_Rates_Monthly" />}>
                  {rate.monthlyPrice && rate.monthlyPrice > 0 ? (
                    <span>
                      <span className="payment-prices">
                        {/*  | money_with_currency:this.props.currency */}
                        <span>{rate.monthlyPrice}</span>
                      </span>
                      <span className="user-prices hide">
                        {/* | divided_by: this.props.currency.conversion} */}
                        <span data-price={rate.monthly_price} />
                      </span>
                    </span>
                  ) : (
                    <span>
                      <span className="payment-prices">-</span>
                    </span>
                  )}
                </td>
              ) : null}
              {this.props.customRateDays > 0 ? (
                <td data-title={this.props.customRateDays + <I18nPlainText keyName="G_Rates_UnitDays" />}>
                  {rate.monthlyPrice > 0 && rate.customPrice ? (
                    <span>
                      <span className="payment-prices">
                        {/* | money_with_currency:this.props.currency */}
                        <span>{rate.customPrice}</span>
                      </span>
                      <span className="user-prices hide">
                        {/* | divided_by: this.props.currency.conversion */}
                        <span data-price={rate.customPrice} />
                      </span>
                    </span>
                  ) : (
                    <span>
                      <span className="payment-prices">-</span>
                    </span>
                  )}
                </td>
              ) : null}
            </tr>
          );
        }
        return null;
      }),
    );
  }
  render() {
    const tableStyle = {
      marginBottom: '10px',
      display: this.props.rooms.length > 1 ? 'none' : null,
    };
    return (
      <div className="house-rate" id="Rates">
        <section className="subtle-box">
          {this.renderExternal()}
          <div className="container">
            <div className="row">
              <div className="col-md-12 table-container">
                {this.props.rooms.map &&
                  this.props.rooms.map(room => (
                    <table
                      className="table responsive-table table-rates table-rates--{{room.id}}"
                      style={tableStyle}
                      key={room.id}
                    >
                      {/* <!--lighter with-rates--> */}
                      <thead>
                        <tr>
                          <th rowSpan="" className="rates-currency">
                            <select id="radio-price" className="form-control">
                              <option value="payment">
                                {this.props.currency.code} ({this.props.currency.symbol})
                              </option>
                              <option value="user" />
                            </select>
                          </th>
                          {this.renderDailyRateTh()}
                          {this.props.hasWeeklyRate ? (
                            <th className="upcase" rowSpan={this.rowsNum}>
                              <I18nText keyName="G_Rates_Weekly" />
                            </th>
                          ) : null}
                          {this.props.hasMonthlyRate ? (
                            <th className="upcase" rowSpan={this.rowsNum}>
                              <I18nText keyName="G_Rates_Monthly" />
                            </th>
                          ) : null}
                          {this.props.customRateDays > 0 ? (
                            <th rowSpan={this.rowsNum}>
                              {this.props.customRateDays} <I18nText keyName="G_Rates_UnitDays" />
                            </th>
                          ) : null}
                        </tr>
                      </thead>

                      <tbody>
                        {this.renderHasNoSeasons(room)}
                        {this.renderTbody(room)}
                      </tbody>
                    </table>
                  ))}
              </div>
            </div>
          </div>
          {this.props.hasAdditionalInfo ? (
            <div className="container additional-info">
              <hr style={{ margin: '0 0 40px 0' }} />
              <div className="row">
                <div className="col-md-3 col-xs-12">
                  <div className="title"><I18nText keyName="TH_WI_RatesTab_AdditionalInfo" /></div>
                </div>
                <div className="col-md-9 col-xs-12">
                  {this.props.rateSettings.cleaningCharge > 0 ? (
                    <div className="col-sm-5 col-xs-12">
                      <div className="title-info"><I18nText keyName="G_Rates_CleaningCharge" />:</div>
                      {/* | money_with_currency:this.props.currency */}
                      <span className="payment-prices">
                        {this.props.rateSettings.cleaningCharge} ({this.props.currency.code})
                      </span>
                      {/* | divided_by: this.props.currency.conversion */}
                      <span className="user-prices hide">
                        <span data-price={this.props.rateSettings.cleaningCharge} /> (<span className="currency-code" />)
                      </span>
                    </div>
                  ) : null}
                  {this.props.rateSettings.miscCharges > 0 ? (
                    <div className="col-sm-5 col-xs-12">
                      <div className="title-info"><I18nText keyName="G_Rates_MiscCharges" /> :</div>
                      {this.props.rateSettings.miscChargesType === 'percentage' ? (
                        // | money
                        <span className="rate-persentage">
                          {this.props.rateSettings.miscCharges} %
                        </span>
                      ) : null}
                      {this.props.rateSettings.miscChargesType === 'fixed' ? (
                        <span>
                          {/* | money_with_currency:this.props.currency */}
                          <span className="payment-prices">
                            {this.props.rateSettings.miscCharges} ({this.props.currency.code})
                          </span>
                          {/* | divided_by: this.props.currency.conversion */}
                          <span className="user-prices hide">
                            <span data-price={this.props.rateSettings.miscCharges} /> (<span className="currency-code" />)
                          </span>
                        </span>
                      ) : null}
                      {this.props.rateSettings.miscChargesType === 'perPersonNight' ? (
                        <span>
                          {/* | money_with_currency:this.props.currency */}
                          <span className="payment-prices">
                            {this.props.rateSettings.miscCharges} ({this.props.currency.code})
                          </span>
                          <span className="user-prices hide">
                            <span data-price="{{this.props.rate_settings.misc_charges | divided_by: this.props.currency.conversion}}" />{' '}
                            (<span className="currency-code" />)
                          </span>
                          <I18nText keyName="G_Rates_PerPersonPerNight" />
                        </span>
                      ) : null}
                    </div>
                  ) : null}
                  {this.props.rateSettings.taxes > 0 ? (
                    <div className="col-sm-5 col-xs-12">
                      <div className="title-info"><I18nText keyName="G_Rates_Taxes" />:</div>
                      {this.props.rateSettings.taxesType === 'percentage' ? (
                        // | money
                        <span className="rate-persentage">{this.props.rateSettings.taxes} %</span>
                      ) : null}
                      {this.props.rateSettings.taxesType === 'fixed' ? (
                        <span>
                          {/* | money_with_currency:this.props.currency */}
                          <span className="payment-prices">
                            {this.props.rateSettings.taxes} ({this.props.currency.code})
                          </span>
                          <span className="user-prices hide">
                            <span data-price="{{this.props.rate_settings.taxes | divided_by: this.props.currency.conversion}}" />{' '}
                            (<span className="currency-code" />)
                          </span>
                        </span>
                      ) : null}
                      {this.props.rateSettings.taxesType === 'perPersonNight' ? (
                        <span>
                          {/* | money_with_currency:this.props.currency */}
                          <span className="payment-prices">
                            {this.props.rateSettings.taxes} ({this.props.currency.code})
                          </span>
                          <span className="user-prices hide">
                            <span data-price="{{this.props.rate_settings.taxes | divided_by: this.props.currency.conversion }}" />{' '}
                            (<span className="currency-code" />)
                          </span>
                          <I18nText keyName="G_Rates_PerPersonPerNight" />
                        </span>
                      ) : null}
                    </div>
                  ) : null}
                  {this.props.rateSettings.checkin > 0 ? (
                    <div className="col-sm-5 col-xs-12">
                      <div className="title-info"><I18nText keyName="G_Rates_CheckInAfter" />:</div>
                      {/* | hour */}
                      <span className="rate-persentage">{this.props.rateSettings.checkin}</span>
                    </div>
                  ) : null}
                  {this.props.rateSettings.checkout > 0 ? (
                    <div className="col-sm-5 col-xs-12">
                      <div className="title-info"><I18nText keyName="G_Rates_CheckOutBefore" />:</div>
                      {/* | hour */}
                      <span className="rate-persentage">{this.props.rateSettings.checkout}</span>
                    </div>
                  ) : null}
                </div>
              </div>
            </div>
          ) : null}
          <div className="container">
            <hr />
            <div className="row">
              <div className="col-md-3 col-xs-12">
                <div className="title"><I18nText keyName="TH_WI_RatesTab_Policies" /></div>
              </div>
              <div className="col-md-9 col-xs-12">
                <div className="row">
                  <div className="col-xs-12">
                    <div className="title-info title-info--bold">
                      <I18nText keyName="TH_PaymentSchedule" />:
                    </div>
                    <span className="policies-text">
                      {this.props.rateSettings.paymentScheduleText}
                    </span>
                  </div>
                  <div className="col-xs-12">
                    <div className="title-info title-info--bold">
                      <I18nText keyName="TH_CancellationPolicy" />:
                    </div>
                    <span className="policies-text">
                      {this.props.rateSettings.cancellationPolicyText}
                    </span>
                  </div>
                  <div className="col-xs-12">
                    <div className="title-info title-info--bold">
                      <I18nText keyName="G_Rates_SecurityDeposit" />:
                    </div>
                    <span className="policies-text">
                      {this.props.rateSettings.securityDepositText}
                    </span>
                  </div>
                </div>
              </div>
            </div>
            <hr />
          </div>
          {this.props.notes ? (
            <div className="container">
              <div className="row">
                <div className="col-md-3 col-xs-12">
                  <div className="title"><I18nText keyName="TH_WI_RatesTab_Notes" /></div>
                </div>
                <div className="col-md-9 col-xs-12">
                  <div className="view-more">
                    <div className="notes__wrapper">{this.props.notes}</div>
                  </div>
                </div>
              </div>
            </div>
          ) : null}
        </section>
      </div>
    );
  }
}

RatesTabWidget.defaultProps = {
  hasWeekDayRate: false,
  hasPerPersonExtraCharge: false,
  notes: '',
  hasMonthlyRate: false,
  period: {},
  rateSettings: {},
  hasAdditionalInfo: false,
  currency: {},
  periods: [],
  customRateDays: 0,
  rooms: [],
  weekdayPrices: [],
  hasWeeklyRate: false,
  showRateName: false,
  hasSeasons: false,
  hasDailyRate: false,
  hasWeekdayRate: false,
  isExternal: false,
  custom_rate_days: 0
};
RatesTabWidget.propTypes = {
  hasWeekDayRate: PropTypes.bool,
  hasPerPersonExtraCharge: PropTypes.bool,
  notes: PropTypes.string,
  hasMonthlyRate: PropTypes.bool,
  rateSettings: PropTypes.objectOf(PropTypes.any),
  hasAdditionalInfo: PropTypes.bool,
  currency: PropTypes.objectOf(PropTypes.any),
  periods: PropTypes.arrayOf(PropTypes.any),
  customRateDays: PropTypes.number,
  rooms: PropTypes.arrayOf(PropTypes.any),
  weekdayPrices: PropTypes.arrayOf(PropTypes.any),
  hasWeeklyRate: PropTypes.bool,
  showRateName: PropTypes.bool,
  hasSeasons: PropTypes.bool,
  hasDailyRate: PropTypes.bool,
  hasWeekdayRate: PropTypes.bool,
  isExternal: PropTypes.bool,
  custom_rate_days: PropTypes.number
};

export default RatesTabWidget;
