import React from 'react';
import PropTypes from 'prop-types';
import {
  I18nText,
  I18nPlainText
} from '../I18n';

const ReviewsTabWidget = props => (
  <section className="ReviewsTabWidget" id="Reviews">
    <div className="row">
      <div className="col-xs-8 col-sm-8 col-md-9">
        {/* | custom_decimal_format: "0.#" */}
        <div className="num-total">{props.rating}</div>
        <div className="ui-total">
          {/* {% reactDeferred StarGroup 0 'onReady' rating:props.rating, size:'19px', hideHandCursor:true -%} */}
          <div>
            <small>
              {(<I18nText keyName="TH_WI_ReviewsTab_BasedOnNReviews" />, props.pagination.itemCount)}
            </small>
          </div>
        </div>
      </div>
      <div className="col-sm-4 col-md-3 button-container">
        <button href="#" id="add-review" className="btn btn-primary">
          <I18nText keyName="TH_WI_ReviewsTab_ButtonAdd" />
        </button>
      </div>
    </div>

    <div className="row">
      <div className="col-md-12">
        <div id="reviews-box">
          <form
            id="reviews-pages-form"
            method="post"
            action="{{props.reviews_url}}"
            data-ajax="true"
            data-ajax-method="POST"
            data-ajax-mode="replace"
            data-ajax-success="reviewsAjaxSuccess()"
            data-ajax-update="#reviews-container"
          >
            <div
              id="reviews-loading"
              className="-loading"
              style={{
                display: 'none',
                textAlign: 'center',
              }}
            >
              <div className="spinner" />
            </div>

            <div id="reviews-container">
              {/* {% use "snippets/reviewstab_list" with model %} */}
            </div>
            <div className="clearfix" />
          </form>
        </div>
      </div>
    </div>

    {props.scoreExternal || props.customBadgesHtml ? (
      <div className="row external-elements">
        <div className="col-md-6">
          <div className="summary-review">
            {props.scoreExternal && props.scoreExternal.type === 'Pdf' ? (
              // | file_url
              <a href={props.scoreExternal} target="_blank">
                <h5>
                  <I18nText keyName="G_ReviewsExternalCertificate" />
                  <small className="muted">({props.scoreExternal.type})</small>
                </h5>
              </a>
            ) : (
              // | image_url: 150,150 | img_tag
              <span>
                <h5><I18nText keyName="G_ReviewsExternalCertificate" /></h5>
                <button href="{{props.score_external | image_url }}" target="_blank">
                  {props.scoreExternal}
                </button>
              </span>
            )}
          </div>
        </div>
        <div className="col-md-6">
          {props.customBadgesHtml ? (
            <div>
              <h5><I18nText keyName="G_ReviewsExternalBadges" /></h5>
              <div id="external-badges-container">{props.customBadgesHtml}</div>
            </div>
          ) : null}
        </div>
      </div>
    ) : null}
    <form
      id="addreview-form"
      method="post"
      action="{{props.add_review_url}}"
      data-ajax="true"
      data-ajax-method="POST"
      data-ajax-begin="ldgfy.reviews.onBeforeAddReview"
      data-ajax-failure="ldgfy.reviews.onErrorAddReview"
      data-ajax-success="ldgfy.reviews.onSuccessAddReview"
    >
      {/* {% content_for_form ReviewsAdd -%} */}

      <div
        className="modal autoModal"
        id="modal-review"
        tabIndex="-1"
        role="dialog"
        aria-labelledby="myModalLabel"
        style={{ display: 'none' }}
      >
        <div className="modal-dialog" role="document">
          <div className="modal-content">
            <div className="modal-header">
              <button type="button" className="close" data-dismiss="modal">
                ×
              </button>
              <h3 id="myModalLabel" className="modal-title">
                <I18nText keyName="TH_WI_ReviewsTab_ButtonAdd" />
              </h3>
            </div>
            <div className="modal-body">
              <div id="review-ok" className="alert alert-success" style={{ display: 'none' }}>
                <span><I18nText keyName="TH_WI_ReviewsTab_ReviewSentOk" /></span>
              </div>

              <div id="review-ko" className="alert alert-error" style={{ display: 'none' }}>
                <span><I18nText keyName="TH_WI_ReviewsTab_ReviewSentKo" /></span>
              </div>
              <div id="review-form-placeholder" className="container-fluid">
                <div className="row">
                  <div className="col-md-12">
                    <fieldset>
                      <div
                        className="validation-summary-valid alert alert-error"
                        data-valmsg-summary="true"
                        id="addreview-validation-summary"
                      >
                        <ul>
                          <li style={{ display: 'none' }} />
                        </ul>
                      </div>
                      <div className="row">
                        <div className="col-md-12">
                          <label htmlFor="StarGroup">
                            <I18nPlainText keyName="TH_WI_ReviewsTab_GiveYourRating" />
                          </label>
                          {/* {% reactDeferred StarGroup 0 'onReady' editable:true, rating:0 ,name:"AddReview.Rating", size:'24px' %} */}
                          <div className="clearfix" />
                        </div>
                      </div>
                      <div className="row">
                        <div className="col-md-6">
                          <label htmlFor="AddReview_Month"><I18nPlainText keyName="G_Month" /></label>
                          <select
                            className="form-control"
                            id="AddReview_Month"
                            name="AddReview.Month"
                            data-val="true"
                            data-val-number={<I18nPlainText keyName={['G_Error_NumberField', 'G_Month']} />}
                            data-val-range={<I18nPlainText keyName={['G_Error_RangeField', 'G_Month']} values={['1', '12']} />}
                            data-val-range-max="12"
                            data-val-range-min="1"
                            data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'G_Month']} />}
                          >
                            {props.availableMouths.map(month => <option value={month.id}>{month.name}</option>)}
                          </select>
                        </div>
                        <div className="col-md-6">
                          <label htmlFor="AddReview_Year">&nbsp;</label>
                          <select
                            className="form-control"
                            id="AddReview_Year"
                            name="AddReview.Year"
                            data-val="true"
                            data-val-number={<I18nPlainText keyName={['G_Error_NumberField', 'G_Year']} />}
                            data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'G_Year']} />}
                          >
                            {props.availableYears.map(year => <option>{year}</option>)}
                          </select>
                        </div>
                      </div>

                      {props.rooms.size > 1 ? (
                        <div className="row">
                          <div className="col-md-6">
                            <label htmlFor="AddReview_SelectedRoomType">
                              <I18nPlainText keyName="G_Apartment" />
                            </label>
                            <select
                              id="AddReview_SelectedRoomType"
                              name="AddReview.SelectedRoomType"
                              className="form-control"
                              data-val="true"
                              data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'G_Apartment', ]} />}
                            >
                              {props.rooms.map(room => <option>{room}</option>)}
                            </select>
                          </div>
                          <div className="col-md-6">
                            <label htmlFor="AddReview_SelectedGuestType">
                              <I18nPlainText keyName="G_GuestType" />
                            </label>
                            <select
                              id="AddReview_SelectedGuestType"
                              name="AddReview.SelectedGuestType"
                              className="form-control"
                              data-val="true"
                              data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'G_GuestType', ]} />}
                            >
                              {props.availableGuestTypes.map(guest => (
                                <option value={guest}>{<I18nPlainText keyName={guest} />}</option>
                              ))}
                            </select>
                          </div>
                        </div>
                      ) : (
                        <div className="col-md-12">
                          <label htmlFor="AddReview_SelectedGuestType">
                            <I18nPlainText keyName="G_GuestType" />
                          </label>
                          <select
                            id="AddReview_SelectedGuestType"
                            name="AddReview.SelectedGuestType"
                            className="form-control"
                            data-val="true"
                            data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'G_GuestType', ]} />}
                          >
                            {props.availableGuestTypes.map(guest => (
                              <option value={guest}>{<I18nPlainText keyName={guest} />}</option>
                            ))}
                          </select>
                        </div>
                      )}
                      <div className="row">
                        <div className="col-md-6">
                          <label htmlFor="AddReview_Author">
                            <I18nPlainText keyName="G_ReviewAuthor" />
                          </label>
                          <input
                            id="AddReview_Author"
                            name="AddReview.Author"
                            type="text"
                            value=""
                            className="form-control"
                            data-val="true"
                            data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'G_ReviewAuthor' ]} />}
                          />
                        </div>
                        <div className="col-md-6">
                          <label htmlFor="AddReview_AuthorLocation">
                            <I18nPlainText keyName="G_ReviewAuthorLocation" />
                          </label>
                          <input
                            id="AddReview_AuthorLocation"
                            name="AddReview.AuthorLocation"
                            type="text"
                            className="form-control"
                            value=""
                          />
                        </div>
                      </div>
                      <div className="row">
                        <div className="col-md-12">
                          <label htmlFor="AddReview_Email"><I18nPlainText keyName="G_Email" /></label>
                          <input
                            id="AddReview_Email"
                            name="AddReview.Email"
                            type="text"
                            value=""
                            className="form-control"
                            data-val="true"
                            data-val-email={<I18nPlainText keyName={['G_Error_EmailNotValid', 'G_Email']} />}
                          />
                          <label htmlFor="AddReview_Title"><I18nPlainText keyName="G_ReviewTitle" /></label>
                          <input
                            className="form-control"
                            id="AddReview_Title"
                            name="AddReview.Title"
                            type="text"
                            value=""
                            data-val="true"
                            data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'G_ReviewTitle']} />}
                          />

                          <label htmlFor="AddReview_Comments">
                            <I18nPlainText keyName="G_ReviewComments" />
                          </label>
                          <textarea
                            cols="20"
                            id="AddReview_Comments"
                            name="AddReview.Comments"
                            rows="2"
                            className="form-control"
                            data-val="true"
                            data-val-required={<I18nPlainText keyName={['G_Error_RequiredField', 'G_ReviewComments' ]} />}
                          />
                        </div>
                      </div>
                    </fieldset>
                    <div className="modal-footer">
                      <button
                        id="resetreview-modal"
                        type="reset"
                        className="btn"
                        style={{ display: 'none' }}
                      >
                        <I18nText keyName="G_Button_Reset" />
                      </button>
                      <button className="btn btn-secondary" data-dismiss="modal">
                        <I18nText keyName="G_Button_Close" />
                      </button>
                      <button
                        id="addreview-modal"
                        type="submit"
                        className="btn btn-primary"
                        data-loading-text={<I18nPlainText keyName="G_Button_Loading" />}
                      >
                        <I18nText keyName="TH_WI_ReviewsTab_ButtonAdd" />
                      </button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </form>
  </section>
);

ReviewsTabWidget.defaultProps = {
  rooms: [],
  availableGuestTypes: [],
  availableYears: [],
  availableMouths: [],
  rating: '',
  scoreExternal: {},
  customBadgesHtml: {},
  pagination: {},
};

ReviewsTabWidget.propTypes = {
  rooms: PropTypes.arraayOf(PropTypes.any),
  availableGuestTypes: PropTypes.arraayOf(PropTypes.any),
  availableYears: PropTypes.arraayOf(PropTypes.any),
  availableMouths: PropTypes.arraayOf(PropTypes.any),
  rating: PropTypes.string,
  scoreExternal: PropTypes.objectOf(PropTypes.any),
  customBadgesHtml: PropTypes.objectOf(PropTypes.any),
  pagination: PropTypes.objectOf(PropTypes.any),
};

export default ReviewsTabWidget;
