import React, { Component } from 'react';
import styled from 'styled-components';
import PropTypes from 'prop-types';

const WidgetContainer = styled.div`height: 100%;`;

const WidgetForm = styled.form`
  display: flex;
  flex-direction: column;
  height: 100%;
`;

const WidgetSelectSize = styled.select`
  display: block;
  width: 70%;
  -webkit-appearance: none;
  border: 1px solid rgba(0, 0, 0, 0.7);
  padding: 1em;
  margin: 2em auto;
`;

const WidgetInputText = styled.input`
  display: block;
  width: 70%;
  -webkit-appearance: none;
  border: 1px solid rgba(0, 0, 0, 0.7);
  padding: 1em;
  margin: 2em auto;
`;

const WidgetFormHeader = styled.h3`
  margin: 0;
  background-color: rgba(0, 0, 0, 0.5);
  color: #ffffff;
  padding: 1em;
  text-align: center;
`;

const SelectContainer = styled.div`
  flex: 1;
  padding: 2em 0;
`;

class HeaderWidgetEditMode extends Component {
  constructor(props) {
    super(props);
    this.updateSize = this.updateSize.bind(this);
    this.updateText = this.updateText.bind(this);
  }

  componentDidMount() {
    this.input.focus();
  }

  resetInput() {
    this.input.value = '';
  }
  updateText(e) {
    // Update the text of the heading
    this.props.updateEditableProp('text', e.target.value);
  }

  updateSize(e) {
    // Update size of the heading
    this.props.updateEditableProp('size', e.target.value);
  }

  render() {
    return (
      <WidgetContainer>
        <WidgetFormHeader>Edit Header</WidgetFormHeader>
        <WidgetForm>
          <SelectContainer>
            <WidgetSelectSize
              defaultValue={this.props.editableProps.size || 'big'}
              onChange={this.updateSize}
            >
              <option value="big">Big</option>
              <option value="medium">Medium</option>
              <option value="small">Small</option>
            </WidgetSelectSize>
            <WidgetInputText
              innerRef={comp => {
                this.input = comp;
              }}
              defaultValue={this.props.editableProps.text}
              onKeyUp={this.updateText}
              placeholder={this.props.editableProps.text}
              type="text"
            />
          </SelectContainer>
        </WidgetForm>
      </WidgetContainer>
    );
  }
}

HeaderWidgetEditMode.propTypes = {
  updateEditableProp: PropTypes.func.isRequired,
  editableProps: PropTypes.shape({
    size: PropTypes.string,
    text: PropTypes.string,
  }).isRequired,
};

export default HeaderWidgetEditMode;
