import React from 'react';
import PropTypes from 'prop-types';

import {
  I18nText,
  I18nPlainText
} from '../I18n';

const AvailabilityTabWidget = props => (
  <div className="house-availability" id="Availability">
    <section className="subtle-box">
      <div className="container">
        {props.rooms.size > 1 ? (
          <div className="row multiple-type-row">
            <div className="col-md-4 col-lg-4 col-sm-6 col-xs-12 select-room-title">
              <h5><I18nText keyName="TH_WI_AvailabilityTap_ViewAvailabilityFor" /></h5>
            </div>
            <div className="col-md-3 col-lg-3 col-sm-3 col-xs-12">
              <select id="availability-select-room" className="form-control">
                <option value="all"><I18nPlainText keyName="TH_WI_AvailabilityTab_AllRooms" /></option>
                {props.rooms.map(room => <option value={room.id}>{room.name}</option>)}
              </select>
            </div>
            <div className="col-md-5 col-lg-5 col-xs-12" style={{ margin: '5px 0' }}>
              <div id="availability-legend">
                <div className="available legend-square" />
                <span><I18nText keyName="TH_WI_AvailabilityTab_Available" /></span>
                <div className="unavailable legend-square" />
                <span><I18nText keyName="TH_WI_AvailabilityTab_Unavailable" /></span>
              </div>
            </div>
            <hr />
          </div>
        ) : (
          <div className="row">
            <div className="col-xs-12">
              <div id="availability-legend">
                <div className="available legend-square" />
                <span><I18nText keyName="TH_WI_AvailabilityTab_Available" /></span>
                <div className="unavailable legend-square" />
                <span><I18nText keyName="TH_WI_AvailabilityTab_Unavailable" /></span>
              </div>
            </div>
          </div>
        )}
      </div>
      <div>
        <div className="row">
          <div className="col-md-12">
            <div id="availability-container">
              <div id="calendar" />
            </div>
          </div>
        </div>
        <div className="container">
          <div className="row">
            <div className="next-prev-container">
              <div className="col-xs-2">
                <a id="calendar-prev">
                  <i className="icon-chevron-left" />
                  <I18nText keyName="TH_WI_RatesTab_Prev" />
                </a>
              </div>
              <div className="col-xs-2 col-xs-offset-8">
                <a id="calendar-next" className="pull-right">
                  <I18nText keyName="TH_WI_RatesTab_Next" />
                  <i className="icon-chevron-right" />
                </a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
    <div className="hidden" data-type="components-initialization">
      {/* | date: yyyyMMdd */}
      <div
        data-component="availability-tab"
        data-start-date={props.start}
        data-end-date={props.end}
        data-url={props.availabilityUrl}
        data-rooms-size={props.rooms.size}
      />
    </div>
  </div>
);

AvailabilityTabWidget.defaultProps = {
  rooms: [],
  start: '',
  end: '',
  availabilityUrl: '',
};

AvailabilityTabWidget.propTypes = {
  rooms: PropTypes.arrayOf(PropTypes.any),
  start: PropTypes.string,
  end: PropTypes.string,
  availabilityUrl: PropTypes.string,
};

export default AvailabilityTabWidget;
