import { getI18nCustomTranslations } from '../api/i18n';

import { basicActionCreator, dataActionCreator, basicErrorAction } from './general';

const initialState = {
  areTranslationsLoaded: false,
  areCustomTranslationsLoaded: false,
  translations: {},
  customTranslations: {},
  isI18nInitialized: false,
  culture: {},
  i18nJsUrl: '',
  pageId: -1
};

/**
 * types
 * @type {string}
 */
export const types = {
  initialize: 'INITIALIZE_I18N',
  updateTranslations: 'UPDATE_GLOBAL_TRANSLATIONS',
  injectI18nFile: {
    start: 'INJECT_FILE_START',
    finish: 'INJECT_FILE_FINISH',
  },
  getI18nCustomTranslations: {
    start: 'CUSTOM_TRANSLATIONS_FETCH_START',
    fail: 'CUSTOM_TRANSLATIONS_FETCH_FAIL',
    finish: 'CUSTOM_TRANSLATIONS_FETCH_FINISH'
  }
};

export const MODULE_NAME = 'i18n';

/**
 * Reducer
 * @param state
 * @param action
 * @returns {*}
 */
export const reducer = (state = initialState, action) => {
  switch (action.type) {
    case types.initialize: {
      return { ...state, ...{ isI18nInitialized: true, ...action.data } };
    }
    case types.updateTranslations: {
      return { ...state, ...{ areTranslationsLoaded: true, translations: { [action.data.l]: action.data.strings } } };
    }
    case types.getI18nCustomTranslations.finish: {
      return { ...state, ...{ areCustomTranslationsLoaded: true, customTranslations: { ...action.data }, } };
    }
    default:
      return state;
  }
};


/**
 Actions
 */
export const ACTIONS = {
  initialize(data) {
    return dispatch => dispatch(dataActionCreator(types.initialize, data));
  },

  updateTranslationsData(data) {
    return dispatch => dispatch(dataActionCreator(types.updateTranslations, data));
  },

  fetchCustomTranslations(pageId, shortCode) {
    return dispatch => {
      dispatch(basicActionCreator(types.getI18nCustomTranslations.start));
      return getI18nCustomTranslations(pageId, shortCode).then(
        response => {
          dispatch(dataActionCreator(types.getI18nCustomTranslations.finish, response));
        },
        (response) => {
          dispatch(basicErrorAction(types.getI18nCustomTranslations.fail, response));
        }
      );
    };
  }
};
