const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const validUrl = require('valid-url');
const execSync = require('child_process').execSync;

const rootPath = path.resolve('.');

const fetchDataViaShell = (url) => {
  console.log(`Fetching model from ${url}`);
  execSync(`wget --quiet \
    --method POST \
    --header 'Content-Type: application/json' \
    --header 'Cache-Control: no-cache' \
    --body-data '{\n "url": "${url}",\n "siteModel": true\n}' \
    --output-document \
    - 'http://fpi.lodgifystaging.com/?controller=Themes&action=GetModelShowPage' \
  > demo/demo.data.json`, {stdio: 'inherit'});
  console.log(`Model from ${url} downloaded successfully`);
};

const commonConfig = {
  entry: './demo/demo.js',
  output: {
    filename: 'demo.js',
    path: path.join(rootPath, 'build')
  },
  plugins: []
};

/**
 * Resolves the entryPoint to be exported
 * @param  {Object} config
 * @return {Object}
 */
const entryResolver = (config, modelUrl) => {
  // common config for static and dynamic model data
  const builtConfig = Object.assign({}, commonConfig, {
    plugins: config.plugins.concat([
      new HtmlWebpackPlugin({
        title: 'Lodgify Template Demo',
        filename: 'index.html',
        template: 'demo/index.html'
      })
    ])
  });

  // if loading dynamic-data based entry point file;
  if (validUrl.isUri(modelUrl)) {
    builtConfig.entry = './demo/demo.dynamic.js';

    try {
      fetchDataViaShell(modelUrl);
    } catch (err) {
      console.error(err);
    }

    return builtConfig;
  }

  console.log('Using static model data in repo');
  // returning static-data based entry point file
  return builtConfig;
};

module.exports = entryResolver;
