/**
 * Check if the environment is either "dev" or "prod", therefore: isValid
 * @param  {String} env
 * @return {Boolean}
 */
const isValidEnvironment = (env) => (env && (env === 'dev' || env === 'prod'));

/**
 * Dynamically loads the environment-dependant configuration and computes the needed
 * entry point
 * @param  {Object} {env, model}
 * @return {Object}
 */
const configResolver = ({ env, model }) => {
  if (!isValidEnvironment(env))
    throw new Error(`No valid environment specified (dev|prod)`);

  // Loads from dumb @lodgify/webpack-config
  const configBuilder = require('@lodgify/webpack-config'); // eslint-disable-line global-require
  const config = configBuilder[`${env}`]({ slug: "liv" });

  // Loads local entry point
  const entry = require(`./entry.${env}.js`)(config, model); // eslint-disable-line

  return Object.assign({}, config, entry);
};

module.exports = configResolver;
