import React, { Component } from 'react';
import PropTypes from 'prop-types';
import zenscroll from 'zenscroll';
import { StickyContainer, Sticky } from 'react-sticky';

import * as widgets from '@lodgify/widgets';

import SlideShow from './components/slideshow/SlideShow';
import styles from './scss/House.scss';

const {
  I18nText,
  I18nPlainText,
  I18nInitializer
} = widgets;

class House extends Component {
  constructor(props) {
    super(props);
    this.state = {
      activeEl: null,
    };
    this.setActiveElement = this.setActiveElement.bind(this);
  }

  componentDidMount() {
    zenscroll.setup(null, 120);
  }

  setActiveElement(e) {
    const activeEl = e.target.getAttribute('href').replace('#', '');
    this.setState({
      activeEl,
    });
  }

  renderWidgets() {
    const isMulti = this.props.websiteMaxProperties > 1;
    return (
      <div className={styles.tabWidgetsContainer}>
        {this.props.propertyTabs.map(widget =>
          Object.keys(widgets).map(w => {
            // TODO ContainerWidget is required in array as is a widget itself
            // checking if widget exists, if ContainerWidget doesn't exist, then return null
            if (widgets[w] && widgets[w].type === widget.widgets[0].type) {
              const Comp = widgets[w].Widget;
              const props = {
                ...widget.widgets[0].props,
                isMulti,
              };
              return (
                <Comp
                  model={this.props.model}
                  key={widgets[w].type}
                  {...props}
                  theme={this.props.theme}
                />
              );
            }
            return null;
          }),
        )}
      </div>
    );
  }
  /* eslint-enable */

  renderSlideShow() {
    return this.props.propertyTabs.map(tab =>
      tab.widgets.map(widget => {
        if (widget.type === 'OverviewTab') {
          const slideshowStyles = {
            height: this.props.propertyTabs.length <= 1 ? '600px' : '500px',
          };
          return (
            <div
              key={widget.id}
              className={this.props.propertyTabs > 1 ? styles.tabWidgetsContainer : undefined}
            >
              <SlideShow
                styles={slideshowStyles}
                data={widget.props}
                hasDots
                hasThemeWidgets
                hasParallax={false}
                images={widget.props.allImages}
                style={{ height: '400px' }}
              />
            </div>
          );
        }
        return null;
      }),
    );
  }

  renderSingleTabSlideShow() {
    const slideshowStyles = {
      height: this.props.propertyTabs.length <= 1 ? '600px' : '500px',
    };
    return (
      <div className={this.props.propertyTabs > 1 ? styles.tabWidgetsContainer : undefined}>
        <SlideShow
          styles={slideshowStyles}
          hasDots
          hasThemeWidgets
          hasParallax={false}
          images={this.props.model.themeWidgets[0].props.images}
          style={{ height: '400px' }}
        />
      </div>
    );
  }

  render() {
    return (
      <StickyContainer>
        <I18nInitializer model={this.props.model} pageId={this.props.pageId} />
        <main id="content" className={styles.main} data-require-mobile-class>
          {this.props.propertyTabs.length === 1 &&
          this.props.propertyTabs[0].linkText === 'Overview' ? (
            <div className={styles.slideshowContainer}>{this.renderSingleTabSlideShow()}</div>
          ) : null}
          {this.props.websiteMaxProperties > 1 ? (
            <div data-context="house-nav-box">
              <div id="widget-container" />
              <div id="contact-info-container">
                <div><I18nPlainText keyName="G_Or" /></div>
                <button
                  id="contact-button-multi"
                  className=""
                  data-toggle="tab"
                  data-target="#ContactTab"
                  href="#Contact"
                >
                  <I18nText keyName="TH_Contact_host" />
                </button>
              </div>
            </div>
          ) : null}
          <div className={styles.housePage}>
            {this.props.propertyTabs.length > 1 && (
              <Sticky topOffset={80} disableCompensation>
                {({
                  isSticky,
                  wasSticky, // eslint-disable-line
                  style, // eslint-disable-line
                  distanceFromTop, // eslint-disable-line
                  distanceFromBottom, // eslint-disable-line
                  calculatedHeight, // eslint-disable-line
                }) => (
                  <div className={`${styles.topContainer} ${isSticky && styles.sticky}`}>
                    <div className={styles.container}>
                      <div className={styles.headerContainer}>
                        <div className={styles.houseMainInfo}>
                          <div className={styles.titles}>
                            {this.props.pageTitle === 'Overview' ||
                            this.props.propertyTabs.size > 1 ? (
                              <span className={styles.houseHeaderName}>
                                {this.props.propertyName}
                              </span>
                            ) : (
                              <span className={styles.houseHeaderTitle}>
                                {this.props.pageTitle}
                              </span>
                            )}
                            {this.props.propertyTabs.length > 1 ? (
                              <div className={styles.subHeader}>
                                {!this.props.propertyAddressHidden ? (
                                  <div className={styles.propertyAddress}>
                                    <i className="icon-map-marker" />
                                    <span className={styles.directions}>
                                      {this.props.propertyCityName
                                        ? this.props.propertyCityName
                                        : null}
                                      {this.props.propertyCountryName
                                        ? `, ${this.props.propertyCountryName}`
                                        : null}
                                    </span>
                                  </div>
                                ) : null}
                                <div className={styles.propertyScore}>
                                  <I18nText keyName="TH_WI_ReviewTab_NotReviewed" />
                                  {/* need to render property score like : reactDeferred StarGroup 0 'onReady' rating:model.property_score, size:'14px' */}
                                  {this.props.propertyScore > 0 ?
                                    <I18nText keyName="TH_WI_ReviewTab_NotReviewed" /> : null}
                                </div>
                                <div className={styles.propertyScore}>
                                  {this.props.propertyScore > 0 ? (
                                    <small>
                                      &nbsp;{' '}
                                      {
                                        ('TH_WI_ReviewsTab_BasedOnNReviews',
                                        this.props.propertyReviewers)
                                      }
                                    </small>
                                  ) : null}
                                </div>
                              </div>
                            ) : null}
                          </div>
                        </div>
                        <div className={styles.priceList}>
                          <span className={styles.price}>95 € / Night</span>
                          {/* reactDeferred PropertyPrices 0 'onReady' propertyId:model.property_id, showPerNight:true */}
                        </div>
                      </div>
                    </div>
                    <ul className={styles.tabNavigation}>
                      {this.props.propertyTabs.map((link, index) => (
                        <li key={link.linkText} className={`${styles.tabElement}`}>
                          <a
                            onClick={this.setActiveElement}
                            key={link.linkText}
                            data-name={link.linkText}
                            href={`#${link.linkText}`}
                            className={`${styles.tabLink} ${this.state.activeEl === link.linkText &&
                              styles.activeTab} ${index === 0 &&
                              !this.state.activeEl &&
                              styles.activeTab}`}
                          >
                            {link.linkText}
                          </a>
                        </li>
                      ))}
                    </ul>
                  </div>
                  /* eslint-enable */
                )}
              </Sticky>
            )}

            <div className={styles.widgetsContainer}>
              {this.props.propertyTabs.length > 1 && this.renderSlideShow()}
              {this.renderWidgets()}
            </div>
          </div>
        </main>
      </StickyContainer>
    );
  }
}

House.defaultProps = {
  propertyTabs: [],
  pageTitle: '',
  propertyName: '',
  theme: {},
  propertyAddressHidden: false,
  propertyCityName: 'Barcelona',
  propertyCountryName: 'Spain',
  propertyScore: 100,
  propertyReviewers: 2,
  websiteMaxProperties: 1,
  isMulti: false,
  model: {},
};

House.propTypes = {
  pageId: PropTypes.number.isRequired,
  propertyTabs: PropTypes.arrayOf(PropTypes.any),
  pageTitle: PropTypes.string,
  propertyName: PropTypes.string,
  theme: PropTypes.objectOf(PropTypes.any),
  propertyAddressHidden: PropTypes.bool,
  propertyCityName: PropTypes.string,
  propertyCountryName: PropTypes.string,
  propertyScore: PropTypes.number,
  propertyReviewers: PropTypes.number,
  websiteMaxProperties: PropTypes.number,
  isMulti: PropTypes.bool,
  model: PropTypes.objectOf(PropTypes.any),
};

export default House;
