import React from 'react';
import styled from 'styled-components';
import PropTypes from 'prop-types';

import styles from '../scss/Header.scss';

const LogoContainer = styled.div`
  width: auto;
  min-width: 100px;
  max-width: 200px;
  height: 100%;
  max-height: 80px;
  margin-top: 0;
  text-indent: 10px;
  flex: 0;
  margin-left: 40px;
  margin-right: 40px;
  position: relative;
  @media screen and (max-width: 1024px) {
    max-width: 100%;
    margin-left: 18%;
    flex-grow: 2;
  }
  @media screen and (max-width: 768px) {
    margin-left: 20%;
  }
  @media screen and (max-width: 500px) {
    width: ${props => (props.theme.logo ? `${props.theme.logo.width}px` : '20%')};
    margin: 0;
    height: 100%;
    display: flex;
    align-items: center;
  }
`;

const LogoHeader = styled.h1`
  color: white;
  font-family: ${props => props.theme.headerFont.name || 'Caveat, cursive'};
  font-size: 2.4vw;
  margin-top: 0;
  margin-bottom: 0;
  height: 100%;
  @media screen and (max-width: 1024px) {
    font-size: 4vw;
  }
  @media screen and (max-width: 768px) {
    font-size: 5vw;
  }
  @media screen and (max-width: 500px) {
    font-size: 7vw;
    min-width: 100%;
  }
`;

const LogoImage = styled.img`
  max-width: 100%;
  height: 90%;
  width: auto;
  left: 0;
  object-fit: contain;
  flex: 0;
  margin-left: 40px;
  margin-right: 40px;

  @media screen and (max-width: 1024px) {
    margin-left: 0;
  }
`;

const LogoText = styled.span``;

const Logo = props =>
  props.logo && props.logo.url ? (
    <LogoImage
      className={styles.logoOnlyImage}
      alt={`${props.logo.websiteTitle} ${props.websiteSubtitle}`}
      width={props.logo.width ? props.logo.width : null}
      height={props.logo.height ? props.logo.height : null}
      src={
        props.logo.url && props.logo.url.length > 0
          ? props.logo.url.replace(/lodgifydevelop/, 'lodgify')
          : null
      }
    />
  ) : (
    <LogoContainer>
      <LogoHeader>
        {props.logo &&
          props.logo.websiteTitle && (
            <LogoText title={props.websiteSubtitle}>{props.logo.websiteTitle}</LogoText>
          )}{' '}
      </LogoHeader>
    </LogoContainer>
  );

Logo.defaultProps = {
  logo: {
    width: 0,
    height: 0,
    url: '',
  },
  websiteTitle: '',
  websiteSubtitle: '',
};

Logo.propTypes = {
  logo: PropTypes.objectOf(PropTypes.any),
  websiteTitle: PropTypes.string,
  websiteSubtitle: PropTypes.string,
};

export default Logo;
