import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

import styles from './FooterLinks.scss';

const FooterLinksContainer = styled.section`
  background-color: ${props => (props.isSubNavList ? props.theme.palette.action : 'transparent')};
`;
const FooterLinksList = styled.ul``;
const FooterLinksItem = styled.li``;

const FooterSubLinkItem = styled.li`
  border-bottom: ${props => (props.isSubNavList ? '1px solid rgba(1, 1, 1, 0.5)' : 'none')};
  height: 40px;
  line-height: 40px;
`;

const FooterLink = styled.a`
  color: ${props => (props.isSubNavList ? '#010101' : '#fff')};
  text-decoration: none;
  font-size: 12px;
  &::before {
    content: '|';
    position: absolute;
    right: -5px;
    color: #fff;
  }
`;

const FooterSubLink = FooterLink.extend``;

const FooterLinks = props => {
  const hasSubNavItems = props.menu.find(el => el.links.length > 0);
  const containerClass = hasSubNavItems
    ? `${styles.FooterLinksList} ${styles.footerLinksSubLinks}`
    : `${styles.FooterLinksList} ${styles.footerLinksNoSubLinks}`;
  return (
    <FooterLinksContainer className={styles.FooterLinksContainer} isSubNavList={hasSubNavItems}>
      <FooterLinksList className={containerClass}>
        {props.menu.map(item => (
          <FooterLinksItem
            key={item.title}
            className={styles.FooterLinksItem}
            isSubNavList={hasSubNavItems}
          >
            <FooterLink
              className={hasSubNavItems ? styles.footerLinkWithSub : null}
              href={item.url}
              isSubNavList={hasSubNavItems}
            >
              {item.title}{' '}
            </FooterLink>
            {item.links.length > 0 ? (
              <ul className={styles.FooterSubList}>
                {item.links.map(subItem => (
                  <FooterSubLinkItem isSubNavList={hasSubNavItems} key={subItem.title}>
                    <FooterSubLink isSubNavList={hasSubNavItems} href={subItem.url}>
                      {subItem.title}
                    </FooterSubLink>
                  </FooterSubLinkItem>
                ))}
              </ul>
            ) : null}
          </FooterLinksItem>
        ))}
      </FooterLinksList>
    </FooterLinksContainer>
  );
};
FooterLinks.propTypes = {
  menu: PropTypes.arrayOf(PropTypes.any).isRequired,
};

export default FooterLinks;
