import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Select from 'react-select';

import 'react-select/dist/react-select.css';
import styles from './Languages.scss';

class LanguageSelector extends Component {
  constructor(props) {
    super(props);
    this.state = {
      cultures: [],
      actualCulture: {},
    };
    this.handleChange = this.handleChange.bind(this);
  }
  componentDidMount() {
    this.mapCultures();
  }

  mapCultures() {
    const cultures = [];
    this.props.availableCultures.map(culture =>
      cultures.push({
        value: culture.isoCode,
        label: culture.name,
      }),
    );

    const actualCulture = {
      value: this.props.culture.isoCode,
      label: this.props.culture.name,
    };

    this.setState({
      cultures,
      actualCulture,
    });
  }

  handleChange(e) {
    this.setState({
      actualCulture: {
        value: e.value,
        label: e.value,
      },
    });
  }

  render() {
    return (
      <Select
        value={this.state.actualCulture.value}
        options={this.state.cultures}
        className={styles.languageSelect}
        onChange={this.handleChange}
      />
    );
  }
}

LanguageSelector.propTypes = {
  availableCultures: PropTypes.arrayOf(PropTypes.any).isRequired,
  culture: PropTypes.objectOf(PropTypes.any).isRequired,
};

export default LanguageSelector;
