import React, { Component } from 'react';
import PropTypes from 'prop-types';
import styled, { css } from 'styled-components';
import classnames from 'classnames';
import styles from './Navigation.scss';

const NavItem = styled.li`
  height: 100%;
  margin-left: 0.5em;
  position: relative;
  text-transform: uppercase;
  &:nth-child(1) {
    margin-left: 0.4em;
  }
  @media screen and (max-width: 1024px) {
    line-height: 3;
    margin: 0 0 1em 0;
  }
  & > a {
    color: ${props => (props.isMulti ? '#010101' : '#fff')};
    text-decoration: none;
    &:hover {
      color: #ffffff;
      text-decoration: none;
    }
    ${props =>
      (props.pinned || props.hasMultipleTabs) &&
      css`
        color: #333;
      `};
    @media screen and (max-width: 1024px) {
      text-decoration: none;
      color: rgba(0, 0, 0, 0.4);
      border: none;
    }
  }
`;

const SubNav = styled.ul`
  box-shadow: 0 20px 30px 0 rgba(0, 0, 0, 0.1);
`;

const SubNavItem = styled.li`
  height: 42px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.1);
  &:hover {
    transition: background 0.3s linear;
    background: ${props => props.theme.palette.action};
  }

  @media screen and (max-width: 1024px) {
    height: 0;
  }
`;

const SubNavLink = styled.a`
  color: rgba(0, 0, 0, 0.4);
  text-decoration: none;
  display: block;
  padding: 0 20px;
  font-size: 13px;
  max-height: 100%;
  line-height: initial;
  display: flex;
  flex-direction: column;
  justify-content: center;
  height: 100%;
  color: #333;
  @media screen and (max-width: 1024px) {
    padding: 0;
  }
  &:hover {
    color: inherit;
    text-decoration: none;
  }
`;

const SubNavItems = props => {
  if (props.item.links && props.item.links.length > 0) {
    const subNavListClass = props.visible
      ? `${styles.subNavList} ${styles.mobile}`
      : styles.subNavList;
    return (
      <SubNav className={subNavListClass}>
        {props.item.links.map(link => (
          <SubNavItem
            className={props.visible ? `${styles.mobile} ${styles.subNavItem}` : styles.subNavItem}
            href={link.url}
            key={link.pageId}
            title={link.title}
            visible={props.visible}
          >
            <SubNavLink className={styles.SubNavLink} href={link.url}>
              {link.title}
            </SubNavLink>
          </SubNavItem>
        ))}
      </SubNav>
    );
  }
  return null;
};

SubNavItems.propTypes = {
  item: PropTypes.objectOf(PropTypes.any).isRequired,
  visible: PropTypes.bool.isRequired,
};
const Link = styled.a`
  font-size: 0.9rem;
`;
class Item extends Component {
  constructor(props) {
    super(props);
    this.handleClick = this.handleClick.bind(this);
  }

  handleClick(e) {
    if (this.props.item.links.length > 0) {
      this.props.showSubNav(e, this.props.item.title);
    }
  }

  render() {
    const itemClassName = classnames(styles.navItem, {
      [styles.isActive]: this.props.isActivePage,
      [styles.isPinned]: this.props.pinned,
      [styles.hasHeroImage]: !this.props.pinned && this.props.hasHeroImage,
      [styles.hasMultipleTabs]: this.props.hasMultipleTabs,
    });

    return (
      <NavItem
        pinned={this.props.pinned}
        className={itemClassName}
        isActivePage={this.props.isActivePage}
        hasMultipleTabs={this.props.hasMultipleTabs}
      >
        <Link
          innerRef={this.props.setRef}
          className={styles.navLink}
          href={this.props.item.url}
          items={this.props.item}
          onClick={this.handleClick}
        >
          {this.props.item.title}
        </Link>
        <SubNavItems
          visible={this.props.visible}
          isMobile={this.props.isMobile}
          item={this.props.item}
        />
      </NavItem>
    );
  }
}

Item.defaultProps = {
  item: {},
  openMobileSubNav: () => {},
  showSubNav: () => {},
  pinned: false,
  isActivePage: false,
  hasMultipleTabs: false,
  hasHeroImage: false,
};

Item.propTypes = {
  item: PropTypes.objectOf(PropTypes.any),
  isMobile: PropTypes.bool.isRequired,
  setRef: PropTypes.func.isRequired,
  showSubNav: PropTypes.func,
  visible: PropTypes.bool.isRequired,
  pinned: PropTypes.bool,
  isActivePage: PropTypes.bool,
  hasMultipleTabs: PropTypes.bool,
  hasHeroImage: PropTypes.bool,
};

export default Item;
