import React, { Component } from 'react';
import styled from 'styled-components';
import PropTypes from 'prop-types';
import MediaQuery from 'react-responsive';

import NavItems from './NavItems';
import MobileTrigger from './MobileTrigger';

import styles from './Navigation.scss';

const NavContainer = styled.div`
  background: ${props => (props.isMobile ? props.theme.palette.action : 'inherit')};
`;

class Navigation extends Component {
  constructor(props) {
    super(props);
    this.state = {
      navWidth: 0,
      comp: null,
      subNavVisible: false,
    };
    this.setRef = this.setRef.bind(this);
    this.showSubNav = this.showSubNav.bind(this);
    this.items = [];
  }

  componentDidMount() {
    global.setTimeout(this.setMaxWidth(), 1000);
    global.addEventListener('resize', this.setMaxWidth);
  }

  setRef(c) {
    if (c) {
      this.items.push(c.offsetWidth);
    }
  }

  setMaxWidth() {
    if (this.items && this.items.length > 0) {
      const navWidth = this.items.reduce((a, b) => a + b + 10, 0);
      const totalWidth = navWidth + this.items.length * 50;
      const headerWith = this.props.header;
      if (totalWidth > headerWith) {
        this.setState({
          showNavMenu: true,
        });
      } else {
        this.setState({
          navWidth: totalWidth,
        });
      }
    }
  }

  showSubNav(e, comp) {
    e.preventDefault();
    if (comp === this.state.comp) {
      this.setState({
        subNavVisible: false,
        comp: null,
      });
    } else {
      this.setState({
        subNavVisible: true,
        comp,
      });
    }
  }

  render() {
    const mainNavClass = this.props.isMobile
      ? `${styles.mainNav} ${styles.isNavOpen}`
      : styles.mainNav;
    const navContainerClass = this.props.isMobile
      ? `${styles.navContainer} ${styles.mobile}`
      : styles.navContainer;
    const navListClass = this.props.isMobile
      ? `${styles.navList} ${styles.mobile}`
      : styles.navList;

    const navStyle = this.state.navWidth > 300 ? { maxWidth: `${this.state.navWidth}px` } : null;

    const isMultiNavClass = this.props.isMulti
      ? `${mainNavClass} ${styles.isMultiNav}`
      : mainNavClass;
    return (
      <nav style={navStyle} className={isMultiNavClass}>
        <NavContainer className={navContainerClass} isMobile={this.props.isMobile}>
          <ul className={navListClass}>
            <MediaQuery maxWidth={1024} values={{ width: 1024 }}>
              <NavItems
                setRef={this.setRef}
                isMobile={this.props.isMobile}
                navItems={this.props.navItems}
                showSubNav={this.showSubNav}
                subNavVisible={this.state.subNavVisible}
                comp={this.state.comp}
                maxMenuItems={this.props.maxMenuItems}
                pageId={this.props.pageId}
                hasHeroImage={this.props.hasHeroImage}
              />
            </MediaQuery>
            <MediaQuery minWidth={1024} values={{ width: 1024 }}>
              <NavItems
                setRef={this.setRef}
                isMobile={this.props.isMobile}
                navItems={this.props.navItems}
                pinned={this.props.pinned}
                actualPage={this.props.actualPage}
                maxMenuItems={this.props.maxMenuItems}
                hasMultipleTabs={this.props.hasMultipleTabs}
                pageId={this.props.pageId}
                hasHeroImage={this.props.hasHeroImage}
              />
            </MediaQuery>
          </ul>
        </NavContainer>
        <MobileTrigger
          showSubNav={this.showSubNav}
          isNavOpen={this.props.isMobile}
          toggleMobile={this.props.toggleMobile}
        />
      </nav>
    );
  }
}

Navigation.defaultProps = {
  isMobile: false,
  pinned: false,
  header: 0,
  actualPage: '',
  maxMenuItems: 10,
  hasMultipleTabs: false,
  pageId: 0,
  hasHeroImage: false,
};

Navigation.propTypes = {
  isMobile: PropTypes.bool.isRequired,
  toggleMobile: PropTypes.func.isRequired,
  navItems: PropTypes.arrayOf(PropTypes.any).isRequired,
  isMulti: PropTypes.bool.isRequired,
  pinned: PropTypes.bool,
  header: PropTypes.number,
  actualPage: PropTypes.string,
  maxMenuItems: PropTypes.number,
  hasMultipleTabs: PropTypes.bool,
  pageId: PropTypes.number,
  hasHeroImage: PropTypes.bool,
};

export default Navigation;
