import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

import styles from './Social.scss';
import Facebook from './Facebook';
import Pinterest from './Pinterest';
import Googleplus from './Google+';
import Twitter from './Twitter';
import Youtube from './Youtube';

// Helper to Capitalize first letter
// as the social type is not capitalized like the component
function capitalize(string) {
  return string.charAt(0).toUpperCase() + string.slice(1);
}

const SocialsContainer = styled.div`
  margin-left: auto;
  display: flex;
  flex-wrap: wrap;
  @media screen and (max-width: 600px) {
    padding: 1em 0;
    width: 100%;
    text-align: center;
  }
`;

const Components = {
  Facebook,
  Pinterest,
  Googleplus,
  Twitter,
  Youtube,
};

const Socials = props => (
  <SocialsContainer className={styles.socialContainer}>
    {props.socialMenu.map(social => {
      const componentName = capitalize(social.type);
      if (Object.prototype.hasOwnProperty.call(Components, componentName)) {
        const Component = Components[componentName];
        return (
          <div key={social.title} className={styles.socialComponent}>
            <Component url={social.url} title={social.title} />
          </div>
        );
      }
      return null;
    })}
  </SocialsContainer>
);

Socials.propTypes = {
  socialMenu: PropTypes.arrayOf(PropTypes.any).isRequired,
};

export default Socials;
