import React from 'react';
import { Provider } from 'react-redux';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import 'normalize.css';

import configureStore from './store';

import SlideShow from './components/slideshow/SlideShow';
import Header from './layout/Header';
import Footer from './layout/Footer';
import House from './House';
import styles from './Main.scss';

const Container = styled.div`
  width: 100%;
  margin: 0 auto;
  min-height: 100vh;
  display: flex;
  flex-direction: column;
  font-family: ${props => props.theme.bodyFont.name};
  font-size: ${props => props.theme.bodyFont.size};

  ${'' /* This part must be inside the widgets */} h1:not(.logo) {
    font-family: ${props => props.theme.headerFont.name};
    font-size: ${props => 70 / props.theme.bodyFont.size}rem;
    margin: 1em 0;
  }
  h3 {
    font-family: ${props => props.theme.headerFont.name};
    font-size: ${props => 42 / props.theme.bodyFont.size}rem;
    margin: 0.5em 0;
  }
  h4 {
    font-family: ${props => props.theme.headerFont.name};
    font-size: ${props => 35 / props.theme.bodyFont.size}rem;
    margin: 0.5em 0;
  }
  h5 {
    font-family: ${props => props.theme.headerFont.name};
    font-size: ${props => 25 / props.theme.bodyFont.size}rem;
    margin: 0.5em 0;
  }
`;

const store = configureStore();

const Template = ({ children, ...model }) => {
  // Check if it has a slideshow/hero image
  const hasThemeWidgets = !!(
    model.siteModel.themeWidgets && model.siteModel.themeWidgets.length > 0
  );
  // Check if is a house tab
  const isHouseTab = !!(model.pageModel.propertyTabs && model.pageModel.propertyTabs.length > 0);
  // Check if is a multi property
  const isMulti = model.siteModel.websiteMaxProperties > 1;
  // Check if is a house tab with multiple tabs
  const hasMultipleTabs = !!(
    model.pageModel.propertyTabs && model.pageModel.propertyTabs.length > 1
  );

  // get images fro SlideShow/hero
  const heroImages = model.siteModel.themeWidgets[0].props.images;

  // check if page has slideshow/hero and if there are images
  const hasHeroImage = model.siteModel.themeWidgets.length > 0 && heroImages.length > 0;

  return (
    <Provider store={store}>
      <Container isMulti={isMulti} className={styles.main}>
        <Header
          navItems={model.siteModel.mainMenu}
          logo={model.siteModel.theme.logo}
          websiteTitle={model.siteModel.websiteTitle}
          websiteSubtitle={model.siteModel.websiteSubtitle}
          hasHeroImage={hasHeroImage}
          theme={model.siteModel.theme}
          isMulti={model.siteModel.websiteMaxProperties > 1}
          actualPage={model.pageModel.pageTitle}
          isHouseTab={isHouseTab}
          hasMultipleTabs={hasMultipleTabs}
          maxMenuItems={model.siteModel.maxPropertiesOnMenu}
          themeWidgets={model.siteModel.themeWidgets}
          pageId={model.pageModel.pageId}
        />
        {model.pageModel.propertyTabs.length <= 0 ? (
          <div className="pages-container">
            <SlideShow
              data={model.siteModel.themeWidgets[0].props}
              id={model.siteModel.themeWidgets[0].id}
              hasDots={false}
              images={heroImages}
              hasThemeWidgets={hasThemeWidgets}
              hasParallax
            />
            <section className={styles.gridContent}>{children}</section>
          </div>
        ) : (
          <House
            {...model.pageModel}
            model={model.siteModel}
            isMulti={isMulti}
            theme={model.siteModel.theme}
          />
        )}
        <Footer
          availableCurrencies={model.siteModel.availableCurrencies}
          currency={model.siteModel.currency}
          socialMenu={model.siteModel.socialMenu}
          contactInfo={model.siteModel.contactInfo}
          culture={model.siteModel.culture}
          availableCultures={model.siteModel.availableCultures}
          telephone={model.siteModel.websitePhone}
          secondaryMenu={model.siteModel.secondaryMenu}
        />
      </Container>
    </Provider>
  );
};

Template.defaultProps = {
  siteModel: {},
  pageModel: {},
};

Template.propTypes = {
  siteModel: PropTypes.objectOf(PropTypes.any).isRequired,
  children: PropTypes.node.isRequired,
};

export default Template;
