import React from 'react';
import PropTypes from 'prop-types';

import LanguageSelector from '../components/languages/LanguageSelector';
import CurrencySelector from '../components/currencies/CurrencySelector';
import Contacts from '../components/contacts/Contacts';
import Socials from '../components/social/Socials';
import Address from '../components/address/Address';
import CopyrightText from '../components/CopyrightText';
import FooterLinks from '../components/footerLinks/FooterLinks';

import styles from '../scss/Footer.scss';

const Footer = props => (
  <footer className={styles.footer}>
    <FooterLinks menu={props.secondaryMenu} />
    <section className={styles.bottomFooterContainer}>
      <div className={styles.bottomFooterGridContainer}>
        <div className={styles.bottomFooterGridContainerTop}>
          <LanguageSelector culture={props.culture} availableCultures={props.availableCultures} />
          <CurrencySelector
            currency={props.currency}
            availableCurrencies={props.availableCurrencies}
          />
          <Contacts telephone={props.telephone} />
          <Socials socialMenu={props.socialMenu} />
        </div>
        <div className={styles.bottomFooterGridContainerBottom}>
          <Address contactInfo={props.contactInfo} />
          <CopyrightText>©2016 Tideway Vacation Rentals. All rights reserved</CopyrightText>
        </div>
      </div>
    </section>
  </footer>
);

Footer.defaultProps = {
  telephone: '',
};

Footer.propTypes = {
  currency: PropTypes.objectOf(PropTypes.any).isRequired,
  availableCurrencies: PropTypes.arrayOf(PropTypes.any).isRequired,
  availableCultures: PropTypes.arrayOf(PropTypes.any).isRequired,
  culture: PropTypes.objectOf(PropTypes.any).isRequired,
  contactInfo: PropTypes.objectOf(PropTypes.any).isRequired,
  socialMenu: PropTypes.arrayOf(PropTypes.any).isRequired,
  telephone: PropTypes.string,
  secondaryMenu: PropTypes.arrayOf(PropTypes.any).isRequired,
};

export default Footer;
