import React from 'react';
import PropTypes from 'prop-types';
import MediaQuery from 'react-responsive';
import Headroom from 'react-headroom';

import Logo from '../components/Logo';
import Navigation from '../components/navigation/Navigation';
import MainHeader from '../components/MainHeader';
import { CtaContainer, BookNowButton } from '../components/BookNowButton';

import styles from '../scss/Header.scss';
import '../scss/headroom.scss';

class Header extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      navIsMobile: false,
      pinned: false,
    };
    this.toggleMobileNav = this.toggleMobileNav.bind(this);
    this.onPin = this.onPin.bind(this);
    this.onUnpin = this.onUnpin.bind(this);
    this.setHeaderState = this.setHeaderState.bind(this);
  }

  onPin() {
    this.setState({
      navIsMobile: this.state.navIsMobile,
      pinned: true,
    });
  }

  onUnpin() {
    this.setState({
      navIsMobile: this.state.navIsMobile,
      pinned: false,
    });
  }

  setHeaderState() {
    this.setState({
      navIsMobile: this.state.navIsMobile,
      pinned: this.state.pinned,
    });
  }

  toggleMobileNav() {
    this.setState({
      navIsMobile: !this.state.navIsMobile,
      pinned: this.state.pinned,
    });
  }

  render() {
    return (
      <Headroom
        onUnfix={this.onUnpin}
        onPin={this.onPin}
        onUnpin={this.onUnpin}
        className={`${this.props.hasMultipleTabs && 'relative'}`}
        disable={this.props.hasMultipleTabs}
      >
        <MainHeader
          hasHeroImage={this.props.hasHeroImage}
          themeWidgets={this.props.themeWidgets}
          isHouseTab={this.props.isHouseTab}
          status={this.state.headerPosition}
          className={styles.mainHeader}
          isMulti={this.props.isMulti}
          pinned={this.state.pinned}
          hasMultipleTabs={this.props.hasMultipleTabs}
          innerRef={c => {
            this.header = c;
          }}
        >
          <MediaQuery maxWidth={600} className={styles.mediaContainer} values={{ width: 600 }}>
            <Navigation
              maxMenuItems={this.props.maxMenuItems}
              navItems={this.props.navItems}
              isMobile={this.state.navIsMobile}
              toggleMobile={this.toggleMobileNav}
              isMulti={this.props.isMulti}
              pageId={this.props.pageId}
              hasHeroImage={this.props.hasHeroImage}
            />
            <Logo
              logo={this.props.logo}
              websiteTitle={this.props.websiteTitle}
              websiteSubtitle={this.props.websiteSubtitle}
            />
          </MediaQuery>
          <MediaQuery
            minWidth={601}
            maxWidth={1024}
            className={styles.mediaContainer}
            values={{ width: 1024 }}
          >
            <Navigation
              maxMenuItems={this.props.maxMenuItems}
              navItems={this.props.navItems}
              isMobile={this.state.navIsMobile}
              toggleMobile={this.toggleMobileNav}
              isMulti={this.props.isMulti}
              hasHeroImage={this.props.hasHeroImage}
              pageId={this.props.pageId}
            />
            <Logo
              logo={this.props.logo}
              websiteTitle={this.props.websiteTitle}
              websiteSubtitle={this.props.websiteSubtitle}
            />
            {!this.props.isMulti && (
              <CtaContainer>
                <BookNowButton pinned={this.state.pinned}>Book Now</BookNowButton>
              </CtaContainer>
            )}
          </MediaQuery>
          <MediaQuery minWidth={1025} className={styles.mediaContainer} values={{ width: 1025 }}>
            <Logo
              logo={this.props.logo}
              websiteTitle={this.props.websiteTitle}
              websiteSubtitle={this.props.websiteSubtitle}
            />

            <Navigation
              setRef={this.setNavRef}
              maxMenuItems={this.props.maxMenuItems}
              navItems={this.props.navItems}
              isMobile={this.state.navIsMobile}
              toggleMobile={this.toggleMobileNav}
              isMulti={this.props.isMulti}
              pinned={this.state.pinned}
              header={this.state.header}
              hasMultipleTabs={this.props.hasMultipleTabs}
              actualPage={this.props.actualPage}
              pageId={this.props.pageId}
              hasHeroImage={this.props.hasHeroImage}
            />

            {!this.props.isMulti ? (
              <CtaContainer className="liv-cta-container">
                <BookNowButton hasHeroImage={this.props.hasHeroImage} pinned={this.state.pinned}>
                  Book Now
                </BookNowButton>
              </CtaContainer>
            ) : null}
          </MediaQuery>
        </MainHeader>
      </Headroom>
    );
  }
}

Header.defaultProps = {
  navItems: [],
  logo: {},
  websiteTitle: '',
  websiteSubtitle: '',
  isHouseTab: false,
  maxMenuItems: 10,
  hasMultipleTabs: false,
  themeWidgets: [],
  hasHeroImage: true,
  pageId: 0,
};

Header.propTypes = {
  navItems: PropTypes.arrayOf(PropTypes.any),
  logo: PropTypes.objectOf(PropTypes.any),
  hasHeroImage: PropTypes.bool.isRequired,
  websiteTitle: PropTypes.string,
  isMulti: PropTypes.bool.isRequired,
  websiteSubtitle: PropTypes.string,
  actualPage: PropTypes.string.isRequired,
  isHouseTab: PropTypes.bool,
  maxMenuItems: PropTypes.number,
  hasMultipleTabs: PropTypes.bool,
  themeWidgets: PropTypes.arrayOf(PropTypes.any),
  pageId: PropTypes.number,
};

export default Header;
