// TODO move to a separate package
import { createStore, applyMiddleware, compose } from 'redux';
import thunk from 'redux-thunk';
import { rootReducer } from '../ducks/combine';

const separator = '******************************************************************************';

const printOutError = (err, action) => {
  /* eslint-disable no-console */
  console.log('');
  console.log(separator);
  console.group(`Caught exception executing action: ${action.type}`); //
  console.log(action);
  console.error(err);
  console.groupEnd();
  console.log(separator);
  console.log('');
  /* eslint-enable no-console */
};

const crashReporter = () => next => action => {
  try {
    return next(action);
  } catch (err) {
    printOutError(err, action);
    throw err;
  }
};

function configureStore() {
  const middlewares = applyMiddleware(crashReporter, thunk);

  // to use on-browser devtools
  const useReduxDevtoolsExtension = window.__REDUX_DEVTOOLS_EXTENSION__; // eslint-disable-line
  if (useReduxDevtoolsExtension) {
    const composeWithDevTools = window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__; // eslint-disable-line
    return createStore(rootReducer, composeWithDevTools(middlewares));
  }

  return createStore(rootReducer, compose(middlewares));
}

// TODO this is a development store

export default configureStore;
