const inquirer = require('inquirer');
const execSync = require('child_process').execSync;

function runCommand(packageName, command) {
  const folder = `./packages/${packageName}`;
  process.chdir(folder);
  execSync(`npm run ${command}`, {stdio: 'inherit'});
}

function displayScriptRelatedQuestions(packageName) {
  const folder = `../packages/${packageName}`;
  const packageJson = require(`${folder}/package.json`);

  inquirer.prompt([
    {
      type: 'list',
      name: 'scriptName',
      message: 'What script do you want to run ?',
      choices: Object.keys(packageJson.scripts),
      default: "start"
    }
  ]).then(function (answers) {
    runCommand(packageName, answers.scriptName);
  });
}

function displayTemplateRelatedQuestions() {
  inquirer.prompt([
    {
      type: 'list',
      name: 'templateName',
      message: 'Which template would you like to use ?',
      choices: ['u001-test-template', 'u002-test2-template'],
      filter: val => `templates/custom/${val}`
    }
  ]).then(function (answers) {
    displayScriptRelatedQuestions(answers.templateName);
  });
}

inquirer.prompt([
  {
    type: 'list',
    name: 'packageType',
    message: 'For which package do you want to run a script ?',
    choices: [
      'create-lodgify-template',
      'lodgify-website-renderer',
      'lodgify-template-livingstone',
      'lodgify-checkout',
      'lodgify-demos',
      'Custom template'
    ],
    filter: function (val) {
      if (val.indexOf('lodgify-template') === 0) {
        return `templates/${val}`
      }

      return val;
    }
  }
]).then(function (answers) {
  if (answers.packageType === 'Custom template') {
    displayTemplateRelatedQuestions();
  } else {
    displayScriptRelatedQuestions(answers.packageType);
  }
});
